from __future__ import annotations

from . import ptq as ptq
from . import ptq_config as ptq_config
from . import ptq_quantizer as ptq_quantizer
from . import ptq_registry as ptq_registry
from . import qat as qat
from .ptq import *
from .ptq_config import *
from .ptq_quantizer import *
from .ptq_registry import *
from .qat import *



from __future__ import annotations

from typing import Any, Optional

def resize_image(img: Any, target_size: Any): ...
def flip(im: Any): ...
def crop_img(im: Any, inner_size: Any, color: bool = ..., test: bool = ...): ...
def decode_jpeg(jpeg_string: Any): ...
def preprocess_img(im: Any, img_mean: Any, crop_size: Any, is_train: Any, color: bool = ...): ...
def load_meta(meta_path: Any, mean_img_size: Any, crop_size: Any, color: bool = ...): ...
def load_image(img_path: Any, is_color: bool = ...): ...
def oversample(img: Any, crop_dims: Any): ...

class ImageTransformer:
    is_color: Any = ...
    def __init__(
        self,
        transpose: Optional[Any] = ...,
        channel_swap: Optional[Any] = ...,
        mean: Optional[Any] = ...,
        is_color: bool = ...,
    ) -> None: ...
    transpose: Any = ...
    def set_transpose(self, order: Any) -> None: ...
    channel_swap: Any = ...
    def set_channel_swap(self, order: Any) -> None: ...
    mean: Any = ...
    def set_mean(self, mean: Any) -> None: ...
    def transformer(self, data: Any): ...



from __future__ import annotations

import abc
from datetime import datetime as datetime
from typing import Any, Optional

class ExecuteError(Exception): ...
class FSFileExistsError(Exception): ...
class FSFileNotExistsError(Exception): ...
class FSTimeOut(Exception): ...
class FSShellCmdAborted(ExecuteError): ...

class FS(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ls_dir(self, fs_path: Any) -> Any: ...
    @abc.abstractmethod
    def is_file(self, fs_path: Any) -> Any: ...
    @abc.abstractmethod
    def is_dir(self, fs_path: Any) -> Any: ...
    @abc.abstractmethod
    def is_exist(self, fs_path: Any) -> Any: ...
    @abc.abstractmethod
    def upload(self, local_path: Any, fs_path: Any) -> Any: ...
    @abc.abstractmethod
    def download(self, fs_path: Any, local_path: Any) -> Any: ...
    @abc.abstractmethod
    def mkdirs(self, fs_path: Any) -> Any: ...
    @abc.abstractmethod
    def delete(self, fs_path: Any) -> Any: ...
    @abc.abstractmethod
    def need_upload_download(self) -> Any: ...
    @abc.abstractmethod
    def rename(self, fs_src_path: Any, fs_dst_path: Any) -> Any: ...
    @abc.abstractmethod
    def mv(self, fs_src_path: Any, fs_dst_path: Any, overwrite: bool = ..., test_exists: bool = ...) -> Any: ...
    @abc.abstractmethod
    def upload_dir(self, local_dir: Any, dest_dir: Any) -> Any: ...
    @abc.abstractmethod
    def list_dirs(self, fs_path: Any) -> Any: ...
    @abc.abstractmethod
    def touch(self, fs_path: Any, exist_ok: bool = ...) -> Any: ...
    @abc.abstractmethod
    def cat(self, fs_path: Optional[Any] = ...) -> Any: ...

class LocalFS(FS, metaclass=abc.ABCMeta):
    def ls_dir(self, fs_path: Any): ...
    def mkdirs(self, fs_path: Any) -> None: ...
    def rename(self, fs_src_path: Any, fs_dst_path: Any) -> None: ...
    def delete(self, fs_path: Any): ...
    def need_upload_download(self): ...
    def is_file(self, fs_path: Any): ...
    def is_dir(self, fs_path: Any): ...
    def is_exist(self, fs_path: Any): ...
    def touch(self, fs_path: Any, exist_ok: bool = ...) -> None: ...
    def mv(self, src_path: Any, dst_path: Any, overwrite: bool = ..., test_exists: bool = ...): ...
    def list_dirs(self, fs_path: Any): ...

class HDFSClient(FS, metaclass=abc.ABCMeta):
    pre_commands: Any = ...
    def __init__(self, hadoop_home: Any, configs: Any, time_out: Any = ..., sleep_inter: int = ...) -> None: ...
    def list_dirs(self, fs_path: Any): ...
    def ls_dir(self, fs_path: Any): ...
    def is_dir(self, fs_path: Any): ...
    def is_file(self, fs_path: Any): ...
    def is_exist(self, fs_path: Any): ...
    def upload_dir(self, local_dir: Any, dest_dir: Any, overwrite: bool = ...) -> None: ...
    def upload(self, local_path: Any, fs_path: Any, multi_processes: int = ..., overwrite: bool = ...): ...
    def download(self, fs_path: Any, local_path: Any, multi_processes: int = ..., overwrite: bool = ...): ...
    def mkdirs(self, fs_path: Any) -> None: ...
    def mv(self, fs_src_path: Any, fs_dst_path: Any, overwrite: bool = ..., test_exists: bool = ...): ...
    def delete(self, fs_path: Any): ...
    def touch(self, fs_path: Any, exist_ok: bool = ...): ...
    def need_upload_download(self): ...
    def cat(self, fs_path: Optional[Any] = ...): ...
    def list_files_info(self, path_list: Any): ...



from __future__ import annotations

from typing import Any, Optional

class UnionFind:
    def __init__(self, elementes: Optional[Any] = ...) -> None: ...
    def find(self, x: Any): ...
    def union(self, x: Any, y: Any) -> None: ...
    def is_connected(self, x: Any, y: Any): ...



from __future__ import annotations

from typing import Any, Optional

def summary(net: Any, input_size: Optional[Any] = ..., dtypes: Optional[Any] = ..., input: Optional[Any] = ...): ...
def summary_string(
    model: Any, input_size: Optional[Any] = ..., dtypes: Optional[Any] = ..., input: Optional[Any] = ...
): ...



from __future__ import annotations

from typing import Any, Optional

from ..._typing import Tensor
from . import layers

class Conv2D(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        num_channels: Any,
        num_filters: Any,
        filter_size: Any,
        stride: int = ...,
        padding: int = ...,
        dilation: int = ...,
        groups: Optional[Any] = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        use_cudnn: bool = ...,
        act: Optional[Any] = ...,
        dtype: str = ...,
    ): ...
    def forward(self, input: Any): ...

class Conv3D(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        num_channels: Any,
        num_filters: Any,
        filter_size: Any,
        stride: int = ...,
        padding: int = ...,
        dilation: int = ...,
        groups: Optional[Any] = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        use_cudnn: bool = ...,
        act: Optional[Any] = ...,
        dtype: str = ...,
    ): ...
    def forward(self, input: Any): ...

class Conv3DTranspose(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        num_channels: Any,
        num_filters: Any,
        filter_size: Any,
        padding: int = ...,
        stride: int = ...,
        dilation: int = ...,
        groups: Optional[Any] = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        use_cudnn: bool = ...,
        act: Optional[Any] = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class Pool2D(layers.Layer):
    def __init__(
        self,
        pool_size: int = ...,
        pool_type: str = ...,
        pool_stride: int = ...,
        pool_padding: int = ...,
        global_pooling: bool = ...,
        use_cudnn: bool = ...,
        ceil_mode: bool = ...,
        exclusive: bool = ...,
        data_format: str = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class Linear(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        input_dim: Any,
        output_dim: Any,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        act: Optional[Any] = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class InstanceNorm(layers.Layer):
    scale: Any = ...
    bias: Any = ...
    def __init__(
        self,
        num_channels: Any,
        epsilon: float = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class BatchNorm(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        num_channels: Any,
        act: Optional[Any] = ...,
        is_test: bool = ...,
        momentum: float = ...,
        epsilon: float = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        dtype: str = ...,
        data_layout: str = ...,
        in_place: bool = ...,
        moving_mean_name: Optional[Any] = ...,
        moving_variance_name: Optional[Any] = ...,
        do_model_average_for_mean_and_var: bool = ...,
        use_global_stats: bool = ...,
        trainable_statistics: bool = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class Dropout(layers.Layer):
    def __init__(
        self, p: float = ..., seed: Optional[Any] = ..., dropout_implementation: str = ..., is_test: bool = ...
    ) -> None: ...
    def forward(self, input: Any): ...

class Embedding(layers.Layer):
    weight: Any = ...
    def __init__(
        self,
        size: Any,
        is_sparse: bool = ...,
        is_distributed: bool = ...,
        padding_idx: Optional[Any] = ...,
        param_attr: Optional[Any] = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class LayerNorm(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        normalized_shape: Any,
        scale: bool = ...,
        shift: bool = ...,
        epsilon: float = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        act: Optional[Any] = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class GRUUnit(layers.Layer):
    activation: Any = ...
    gate_activation: Any = ...
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        size: Any,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        activation: str = ...,
        gate_activation: str = ...,
        origin_mode: bool = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any, hidden: Any): ...

class NCE(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        num_total_classes: Any,
        dim: Any,
        sample_weight: Optional[Any] = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        num_neg_samples: Optional[Any] = ...,
        sampler: str = ...,
        custom_dist: Optional[Any] = ...,
        seed: int = ...,
        is_sparse: bool = ...,
        dtype: str = ...,
    ): ...
    def forward(self, input: Any, label: Any, sample_weight: Optional[Any] = ...): ...

class PRelu(layers.Layer):
    weight: Any = ...
    def __init__(
        self,
        mode: Any,
        channel: Optional[Any] = ...,
        input_shape: Optional[Any] = ...,
        param_attr: Optional[Any] = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class BilinearTensorProduct(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        input1_dim: Any,
        input2_dim: Any,
        output_dim: Any,
        name: Optional[Any] = ...,
        act: Optional[Any] = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, x: Any, y: Any): ...

class Conv2DTranspose(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        num_channels: Any,
        num_filters: Any,
        filter_size: Any,
        output_size: Optional[Any] = ...,
        padding: int = ...,
        stride: int = ...,
        dilation: int = ...,
        groups: Optional[Any] = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        use_cudnn: bool = ...,
        act: Optional[Any] = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class SequenceConv(layers.Layer):
    def __init__(
        self,
        name_scope: Any,
        num_filters: Any,
        filter_size: int = ...,
        filter_stride: int = ...,
        padding: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        param_attr: Optional[Any] = ...,
        act: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class RowConv(layers.Layer):
    def __init__(
        self, name_scope: Any, future_context_size: Any, param_attr: Optional[Any] = ..., act: Optional[Any] = ...
    ) -> None: ...
    def forward(self, input: Any): ...

class GroupNorm(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        channels: Any,
        groups: Any,
        epsilon: float = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        act: Optional[Any] = ...,
        data_layout: str = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any): ...

class SpectralNorm(layers.Layer):
    weight_u: Any = ...
    weight_v: Any = ...
    def __init__(
        self, weight_shape: Any, dim: int = ..., power_iters: int = ..., eps: float = ..., dtype: str = ...
    ) -> None: ...
    def forward(self, weight: Any): ...

class TreeConv(layers.Layer):
    bias: Any = ...
    weight: Any = ...
    def __init__(
        self,
        feature_size: Any,
        output_size: Any,
        num_filters: int = ...,
        max_depth: int = ...,
        act: str = ...,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        name: Optional[Any] = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, nodes_vector: Any, edge_set: Any): ...

class Flatten(layers.Layer):
    start_axis: Any = ...
    stop_axis: Any = ...
    def __init__(self, start_axis: int = ..., stop_axis: int = ...) -> None: ...
    def forward(self, input: Tensor) -> Tensor: ...
    __call__ = forward



from __future__ import annotations

import unittest
from typing import Any, Optional

from PIL import ImageEnhance as ImageEnhance

DATA_DIM: int
THREAD: int
BUF_SIZE: int
DATA_DIR: str
img_mean: Any
img_std: Any

def resize_short(img: Any, target_size: Any): ...
def crop_image(img: Any, target_size: Any, center: Any): ...
def process_image(sample: Any, mode: Any, color_jitter: Any, rotate: Any): ...
def val(data_dir: Any = ...): ...

class TestPostTrainingQuantization(unittest.TestCase):
    int8_download: str = ...
    cache_folder: Any = ...
    data_cache_folder: str = ...
    batch_size: Any = ...
    sample_iterations: Any = ...
    infer_iterations: Any = ...
    root_path: Any = ...
    int8_model: Any = ...
    def setUp(self) -> None: ...
    def tearDown(self) -> None: ...
    def cache_unzipping(self, target_folder: Any, zip_path: Any) -> None: ...
    def download_data(self, data_urls: Any, data_md5s: Any, folder_name: Any, is_model: bool = ...): ...
    def download_model(self) -> None: ...
    def run_program(self, model_path: Any, batch_size: Any, infer_iterations: Any): ...
    def generate_quantized_model(
        self,
        model_path: Any,
        quantizable_op_type: Any,
        algo: str = ...,
        round_type: str = ...,
        is_full_quantize: bool = ...,
        is_use_cache_file: bool = ...,
        is_optimize_model: bool = ...,
        onnx_format: bool = ...,
        skip_tensor_list: Optional[Any] = ...,
    ) -> None: ...
    def run_test(
        self,
        model: Any,
        algo: Any,
        round_type: Any,
        data_urls: Any,
        data_md5s: Any,
        quantizable_op_type: Any,
        is_full_quantize: Any,
        is_use_cache_file: Any,
        is_optimize_model: Any,
        diff_threshold: Any,
        onnx_format: bool = ...,
        skip_tensor_list: Optional[Any] = ...,
    ) -> None: ...

class TestPostTrainingKLForMobilenetv1(TestPostTrainingQuantization):
    def test_post_training_kl_mobilenetv1(self) -> None: ...

class TestPostTrainingavgForMobilenetv1(TestPostTrainingQuantization):
    def test_post_training_avg_mobilenetv1(self) -> None: ...

class TestPostTraininghistForMobilenetv1(TestPostTrainingQuantization):
    def test_post_training_hist_mobilenetv1(self) -> None: ...

class TestPostTrainingAbsMaxForMobilenetv1(TestPostTrainingQuantization):
    def test_post_training_abs_max_mobilenetv1(self) -> None: ...

class TestPostTrainingAvgONNXFormatForMobilenetv1(TestPostTrainingQuantization):
    def test_post_training_onnx_format_mobilenetv1(self) -> None: ...

class TestPostTrainingForMobilenetv1SkipOP(TestPostTrainingQuantization):
    def test_post_training_mobilenetv1_skip(self) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.utils import gast

class NameVisitor(gast.NodeVisitor):
    current_seen_vars: Any = ...
    current_loop: Any = ...
    nodes_with_scope: Any = ...
    blacklist_names: Any = ...
    before_loop_body_vars: Any = ...
    in_loop_vars: Any = ...
    write_in_loop: Any = ...
    condition_vars: Any = ...
    in_condition: bool = ...
    type_vars: Any = ...
    static_analysis_visitor: Any = ...
    node_to_wrapper_map: Any = ...
    def __init__(self, root_node: Any) -> None: ...
    def get_loop_var_names(self, node: Any): ...
    def visit_Name(self, node: Any) -> None: ...
    def visit_FunctionDef(self, node: Any) -> None: ...
    def visit(self, node: Any): ...
    def visit_Attribute(self, node: Any) -> None: ...
    def visit_For(self, node: Any) -> None: ...
    def visit_While(self, node: Any) -> None: ...
    def visit_Call(self, node: Any) -> None: ...

class LoopTransformer(gast.NodeTransformer):
    wrapper_root: Any = ...
    root: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    name_visitor: Any = ...
    def transform(self) -> None: ...
    def visit(self, node: Any): ...
    def replace_stmt_list(self, body_list: Any) -> None: ...
    def get_for_stmt_nodes(self, node: Any): ...
    def get_while_stmt_nodes(self, node: Any): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.framework import default_main_program as default_main_program

MODEL_PARALLEL_RNG: str

class RNGStatesTracker:
    states_: Any = ...
    seeds_: Any = ...
    def __init__(self) -> None: ...
    def reset(self) -> None: ...
    def add(self, name: Any, seed: Any) -> None: ...
    def get_states_tracker(self): ...
    def set_states_tracker(self, states: Any) -> None: ...
    def rng_state(self, name: Any = ...) -> None: ...

RNG_STATE_TRACKER: Any

def get_rng_state_tracker(): ...
def model_parallel_random_seed(seed: Optional[Any] = ...) -> None: ...
def determinate_seed(rng_name: Any): ...
def dropout(
    x: Any,
    p: float = ...,
    axis: Optional[Any] = ...,
    rng_name: Optional[Any] = ...,
    training: bool = ...,
    mode: str = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from typing import Any

class PSDispatcher:
    def __init__(self, pserver_endpoints: Any) -> None: ...
    @property
    def eps(self): ...
    def reset(self) -> None: ...
    def dispatch(self, varlist: Any) -> None: ...

class HashName(PSDispatcher):
    def __init__(self, pserver_endpoints: Any) -> None: ...
    def dispatch(self, varlist: Any): ...

class RoundRobin(PSDispatcher):
    def __init__(self, pserver_endpoints: Any) -> None: ...
    def dispatch(self, varlist: Any): ...



from __future__ import annotations

from typing import Any

from .dygraph import Layer

class SimpleLayer(Layer):
    def __init__(self, input_size: Any) -> None: ...
    def forward(self, inputs: Any): ...

def run_check(): ...



from __future__ import annotations

from typing import Any, Optional

def segment_sum(data: Any, segment_ids: Any, name: Optional[Any] = ...): ...
def segment_mean(data: Any, segment_ids: Any, name: Optional[Any] = ...): ...
def segment_min(data: Any, segment_ids: Any, name: Optional[Any] = ...): ...
def segment_max(data: Any, segment_ids: Any, name: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any

from paddle.distributed.fleet.meta_optimizers.sharding.utils import *

class Shard:
    global_params: Any = ...
    worker_idx: int = ...
    worker_num: int = ...
    global_param2device: Any = ...
    device2global_params: Any = ...
    def __init__(self) -> None: ...
    def setup(self, params_grads: Any, worker_idx: Any, worker_num: Any) -> None: ...
    def has_param(self, var_name: Any): ...
    def has_opt_var(self, var_name: Any): ...
    def has_var(self, var_name: Any): ...
    def find_broadcast_params(self, block: Any): ...
    def device(self, var_name: Any): ...
    def is_param(self, var_name: Any): ...
    def is_opti_var(self, var_name: Any): ...
    def filter_grads(self, grads: Any): ...

class ProgramSegment:
    def __init__(self, block: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def is_valid_list_index(list: Any, index: Any): ...
def is_dim_shard(mapping: Any): ...
def is_dim_replicate(mapping: Any): ...
def compute_compatible_dim_mapping(dim_mappings: Any): ...
def compute_compatible_dims_mapping(dims_mapping_list: Any): ...
def compute_compatible_process_mesh(process_mesh_list: Any): ...
def compute_compatible_and_update_dim_mapping(dims_mapping_list: Any, index_list: Any): ...
def append_distributed_attr_suffix(name: Any): ...
def remove_distributed_attr_suffix(name: Any): ...
def check_distributed_attr_for_program(program: Any, dist_context: Optional[Any] = ...): ...
def print_program_with_dist_attr(program: Any, dist_context: Optional[Any] = ...) -> None: ...
def make_data_unshard(dist_main_prog: Any, dist_startup_prog: Any, dist_context: Optional[Any] = ...) -> None: ...
def save_distributed_checkpoint(
    program: Any,
    checkpoint_path: Any,
    dist_attr_path: Any,
    addition_info: Optional[Any] = ...,
    is_integrated: bool = ...,
    dist_context: Optional[Any] = ...,
) -> None: ...
def load_distributed_checkpoint(checkpoint_path: Any, dist_attr_path: Any): ...
def load_checkpoint_into_program(
    checkpoint_path: Any, dist_attr_path: Any, program: Any, dist_context: Optional[Any] = ...
): ...
def load_parameter_into_program(param_dict: Any, program: Any) -> None: ...
def get_dist_attr(program: Any, dist_context: Optional[Any] = ...): ...
def merge_and_slice_parameter(dist_param_dict: Any, pre_dist_attr: Any, cur_dist_attr: Any): ...
def set_grad_var_shape(program: Any, dist_context: Any) -> None: ...

OP_ROLE_KEY: Any

def is_forward_op(op: Any): ...
def is_backward_op(op: Any): ...
def is_loss_op(op: Any): ...
def get_loss_op(block: Any): ...
def set_var_dist_attr(dist_context: Any, var: Any, dims_mapping: Any, process_mesh: Any, **kwargs: Any): ...
def naive_set_dist_op_attr_for_program_by_mesh_and_mapping(
    new_op: Any, process_mesh: Any, ref_mapping: Any, ctx: Any
) -> None: ...
def update_op_dims_mapping_by_default_dist_impl(dist_op: Any): ...
def update_op_dims_mapping_by_elementwise_like_dist_impl(dist_op: Any): ...
def get_all_distributed_main_program(serial_program_info: Any, dist_context: Any, parallelizer: Any): ...

class SerialProgramInfo:
    def __init__(
        self, train_program: Any, satrtup_program: Any, loss: Any, optimizer: Any, cluster: Optional[Any] = ...
    ) -> None: ...
    @property
    def train_program(self): ...
    @property
    def startup_program(self): ...
    @property
    def loss(self): ...
    @property
    def optimizer(self): ...
    @property
    def cluster(self): ...

def get_standalone_cost_data(distributed_programs: Any): ...
def set_dist_op_desc_original_id(dist_op_desc: Any, op_desc: Any, dist_context: Any) -> None: ...
def to_list(value: Any): ...



from __future__ import annotations

from typing import Any

from .auto_parallel_amp import AMPPass as AMPPass
from .pass_base import register_pass as register_pass

world_process_group: Any
__amp_skip_ops__: Any

def set_op_dtype_to_fp16(op: Any) -> None: ...

class FP16State:
    program: Any = ...
    amp_list: Any = ...
    use_fp16_guard: Any = ...
    dist_context: Any = ...
    grad_op_to_op_map: Any = ...
    forward_non_leaf_tensors: Any = ...
    forward_input_cast_ops: Any = ...
    is_train: bool = ...
    def __init__(self, program: Any, amp_list: Any, dist_context: Any, use_fp16_guard: Any) -> None: ...
    def set_var_to_fp16(self, var_name: Any, block: Any) -> None: ...
    def resolute_tensor_dtype(self, block: Any) -> None: ...
    def cast_block(self, block: Any) -> None: ...

class FP16Pass(AMPPass):
    def __init__(self) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.distributed.passes import PassContext as PassContext

from .public import *

class PsProgramBuilder:
    pass_ctx: Any = ...
    attrs: Any = ...
    loss: Any = ...
    cloned_main: Any = ...
    cloned_startup: Any = ...
    use_ps_gpu: Any = ...
    use_heter_ps: Any = ...
    is_worker: Any = ...
    is_heter_worker: Any = ...
    ps_mode: Any = ...
    launch_barrier: Any = ...
    launch_barrier_flag: Any = ...
    server_endpoints: Any = ...
    def __init__(self, pass_ctx: Any) -> None: ...

class GeoPsProgramBuilder(PsProgramBuilder):
    def __init__(self, pass_ctx: Any) -> None: ...

class CpuSyncPsProgramBuilder(PsProgramBuilder):
    def __init__(self, pass_ctx: Any) -> None: ...

class CpuAsyncPsProgramBuilder(CpuSyncPsProgramBuilder):
    def __init__(self, pass_ctx: Any) -> None: ...

class GpuPsProgramBuilder(PsProgramBuilder):
    def __init__(self, pass_ctx: Any) -> None: ...

class HeterAsyncPsProgramBuilder(PsProgramBuilder):
    def __init__(self, pass_ctx: Any) -> None: ...

class FlPsProgramBuilder(PsProgramBuilder):
    def __init__(self, pass_ctx: Any) -> None: ...



from __future__ import annotations

from typing import Any

from ..utils import set_dist_op_desc_original_id as set_dist_op_desc_original_id
from .common import DistributedOperatorImpl as DistributedOperatorImpl
from .common import DistributedOperatorImplContainer as DistributedOperatorImplContainer
from .common import (
    register_distributed_operator_impl as register_distributed_operator_impl,
)
from .common import (
    register_distributed_operator_impl_container as register_distributed_operator_impl_container,
)

class DistributedUpdateLossScaling(DistributedOperatorImplContainer):
    def __init__(self, op_type: Any) -> None: ...

class DistributedUpdateLossScalingImpl(DistributedOperatorImpl):
    def __init__(self, name: Any) -> None: ...
    def is_input_compatible(self, dist_op: Any) -> None: ...
    def is_output_compatible(self, dist_op: Any) -> None: ...
    def is_auto_compatible(self, dist_op: Any) -> None: ...
    def update_dims_mapping(self, dist_op: Any) -> None: ...
    @staticmethod
    def forward(ctx: Any, *args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def backward(ctx: Any, *args: Any, **kwargs: Any) -> None: ...



from __future__ import annotations

from typing import Any

from .worker import get_worker_info as get_worker_info

class _DataLoaderIterBase:
    def __init__(self, loader: Any) -> None: ...
    def __iter__(self) -> Any: ...
    def __len__(self): ...

class _DataLoaderIterSingleProcess(_DataLoaderIterBase):
    def __init__(self, loader: Any) -> None: ...
    def __next__(self): ...
    def next(self): ...
    def __del__(self) -> None: ...

class _DataLoaderIterMultiProcess(_DataLoaderIterBase):
    def __init__(self, loader: Any) -> None: ...
    def __del__(self) -> None: ...
    def __next__(self): ...
    def next(self): ...



from __future__ import annotations

from typing import Any

def log(ctx: Any) -> None: ...
def process_args(ctx: Any) -> None: ...
def collective_compatible(ctx: Any) -> None: ...
def rewrite_host_ip(ctx: Any) -> None: ...

enabled_plugins: Any



from __future__ import annotations

from typing import Any, Optional

from ...fluid.initializer import UniformInitializer as UniformInitializer

class Uniform(UniformInitializer):
    def __init__(self, low: Any = ..., high: float = ..., name: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

import numpy as np

from .. import Tensor
from .._typing import DTypeLike, NestedNumbericSequence, Numberic, ShapeLike
from ..fluid.data_feeder import check_dtype as check_dtype
from ..fluid.data_feeder import check_type as check_type
from ..fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ..fluid.data_feeder import convert_dtype as convert_dtype
from ..fluid.framework import in_dygraph_mode as in_dygraph_mode
from ..fluid.layer_helper import LayerHelper as LayerHelper
from ..fluid.layers import linspace as linspace
from ..fluid.layers import tensor as tensor
from ..fluid.layers import utils as utils
from ..framework import OpProtoHolder as OpProtoHolder
from ..framework import convert_np_dtype_to_dtype_ as convert_np_dtype_to_dtype_
from ..framework import core as core
from ..framework import dygraph_only as dygraph_only
from ..static import Variable as Variable
from ..static import device_guard as device_guard

def to_tensor(
    data: Numberic | NestedNumbericSequence | np.ndarray[Any, Any] | Tensor,
    dtype: Optional[str | np.dtype[Any]] = ...,  # TODO: paddle.dtype
    place: Optional[Any] = ...,  # TODO: CPUPlace | CUDAPinnedPlace | CUDAPlace
    stop_gradient: bool = ...,
) -> Tensor: ...
def full_like(x: Any, fill_value: Any, dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def ones(
    shape: ShapeLike,
    dtype: Optional[DTypeLike] = ...,
    name: Optional[str] = ...,
) -> Tensor: ...
def ones_like(x: Any, dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def zeros(shape: Any, dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def zeros_like(x: Any, dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def eye(num_rows: Any, num_columns: Optional[Any] = ..., dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def full(
    shape: ShapeLike,
    fill_value: bool | int | float | Tensor,
    dtype: Optional[Any] = ...,
    name: Optional[Any] = ...,
) -> Tensor: ...
def arange(
    start: int = ..., end: Optional[Any] = ..., step: int = ..., dtype: Optional[Any] = ..., name: Optional[Any] = ...
): ...
def tril(x: Any, diagonal: int = ..., name: Optional[Any] = ...): ...
def triu(x: Any, diagonal: int = ..., name: Optional[Any] = ...): ...
def meshgrid(*args: Any, **kwargs: Any): ...
def diagflat(x: Any, offset: int = ..., name: Optional[Any] = ...): ...
def diag(x: Any, offset: int = ..., padding_value: int = ..., name: Optional[Any] = ...): ...
def empty(shape: Any, dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def empty_like(x: Any, dtype: Optional[Any] = ..., name: Optional[Any] = ...): ...
def assign(x: Any, output: Optional[Any] = ...): ...
def clone(x: Any, name: Optional[Any] = ...): ...
def complex(real: Any, imag: Any, name: Optional[Any] = ...): ...



from __future__ import annotations

from ...fluid.contrib.layers import sparse_embedding as sparse_embedding
from ...fluid.input import embedding as embedding
from ...fluid.layers import batch_norm as batch_norm
from ...fluid.layers import bilinear_tensor_product as bilinear_tensor_product
from ...fluid.layers import case as case
from ...fluid.layers import cond as cond
from ...fluid.layers import conv2d as conv2d
from ...fluid.layers import conv2d_transpose as conv2d_transpose
from ...fluid.layers import conv3d as conv3d
from ...fluid.layers import conv3d_transpose as conv3d_transpose
from ...fluid.layers import crf_decoding as crf_decoding
from ...fluid.layers import data_norm as data_norm
from ...fluid.layers import group_norm as group_norm
from ...fluid.layers import instance_norm as instance_norm
from ...fluid.layers import layer_norm as layer_norm
from ...fluid.layers import multi_box_head as multi_box_head
from ...fluid.layers import nce as nce
from ...fluid.layers import prelu as prelu
from ...fluid.layers import py_func as py_func
from ...fluid.layers import row_conv as row_conv
from ...fluid.layers import spectral_norm as spectral_norm
from ...fluid.layers import switch_case as switch_case
from ...fluid.layers import while_loop as while_loop
from ...fluid.layers.sequence_lod import sequence_concat as sequence_concat
from ...fluid.layers.sequence_lod import sequence_conv as sequence_conv
from ...fluid.layers.sequence_lod import sequence_enumerate as sequence_enumerate
from ...fluid.layers.sequence_lod import sequence_expand as sequence_expand
from ...fluid.layers.sequence_lod import sequence_expand_as as sequence_expand_as
from ...fluid.layers.sequence_lod import sequence_first_step as sequence_first_step
from ...fluid.layers.sequence_lod import sequence_last_step as sequence_last_step
from ...fluid.layers.sequence_lod import sequence_pad as sequence_pad
from ...fluid.layers.sequence_lod import sequence_pool as sequence_pool
from ...fluid.layers.sequence_lod import sequence_reshape as sequence_reshape
from ...fluid.layers.sequence_lod import sequence_reverse as sequence_reverse
from ...fluid.layers.sequence_lod import sequence_scatter as sequence_scatter
from ...fluid.layers.sequence_lod import sequence_slice as sequence_slice
from ...fluid.layers.sequence_lod import sequence_softmax as sequence_softmax
from ...fluid.layers.sequence_lod import sequence_unpad as sequence_unpad
from .common import deform_conv2d as deform_conv2d
from .common import fc as fc



from __future__ import annotations

from typing import Any, Optional

class Stack:
    items: Any = ...
    def __init__(self) -> None: ...
    def push(self, item: Any) -> None: ...
    def pop(self): ...
    def is_empty(self): ...
    def peek(self): ...

class Event:
    reader_cost_averager: Any = ...
    batch_cost_averager: Any = ...
    total_samples: int = ...
    total_iters: int = ...
    skip_iter: int = ...
    reader_records: Any = ...
    batch_records: Any = ...
    speed_records: Any = ...
    reader: Any = ...
    need_record: bool = ...
    speed_mode: str = ...
    speed_unit: str = ...
    def __init__(self) -> None: ...
    def reset(self) -> None: ...
    def record_reader(self, usetime: Any) -> None: ...
    def record_batch(self, usetime: Any, num_samples: Optional[Any] = ...) -> None: ...
    def reader_average(self): ...
    def batch_average(self): ...
    def speed_average(self): ...
    def get_summary(self): ...

class Hook:
    def begin(self, benchmark: Any) -> None: ...
    def end(self, benchmark: Any) -> None: ...
    def before_reader(self, benchmark: Any) -> None: ...
    def after_reader(self, benchmark: Any) -> None: ...
    def after_step(self, benchmark: Any) -> None: ...

class TimerHook(Hook):
    start_time: Any = ...
    start_reader: Any = ...
    def __init__(self) -> None: ...
    def begin(self, benchmark: Any) -> None: ...
    def before_reader(self, benchmark: Any) -> None: ...
    def after_reader(self, benchmark: Any) -> None: ...
    def after_step(self, benchmark: Any) -> None: ...
    def end(self, benchmark: Any) -> None: ...

class TimeAverager:
    def __init__(self) -> None: ...
    def reset(self) -> None: ...
    def record(self, usetime: Any, num_samples: Optional[Any] = ...) -> None: ...
    def get_average(self): ...
    def get_ips_average(self): ...
    def get_step_average(self): ...

class Benchmark:
    num_samples: Any = ...
    hooks: Any = ...
    current_event: Any = ...
    events: Any = ...
    def __init__(self) -> None: ...
    def step(self, num_samples: Optional[Any] = ...) -> None: ...
    def step_info(self, unit: Any): ...
    def begin(self) -> None: ...
    def before_reader(self) -> None: ...
    def after_reader(self) -> None: ...
    def after_step(self) -> None: ...
    def end(self) -> None: ...
    def check_if_need_record(self, reader: Any) -> None: ...

def benchmark(): ...



from __future__ import annotations

from ...fluid.initializer import Bilinear as Bilinear
from ...fluid.initializer import Initializer as Initializer
from ...fluid.initializer import calculate_gain as calculate_gain
from ...fluid.initializer import set_global_initializer as set_global_initializer
from .assign import Assign as Assign
from .constant import Constant as Constant
from .dirac import Dirac as Dirac
from .kaiming import KaimingNormal as KaimingNormal
from .kaiming import KaimingUniform as KaimingUniform
from .normal import Normal as Normal
from .normal import TruncatedNormal as TruncatedNormal
from .orthogonal import Orthogonal as Orthogonal
from .uniform import Uniform as Uniform
from .xavier import XavierNormal as XavierNormal
from .xavier import XavierUniform as XavierUniform



from __future__ import annotations

from .ps_program_builder import *
from .public import *

class PsProgramBuilderFactory:
    def __init__(self) -> None: ...

# Names in __all__ with no definition:
#   CpuAsyncPsProgramBuilder
#   CpuSyncPsProgramBuilder
#   FlPsProgramBuilder
#   GeoPsProgramBuilder
#   GpuPsProgramBuilder
#   HeterAsyncPsProgramBuilder
#   PsProgramBuilder



from __future__ import annotations

from typing import Any

def get_cloud_cluster(args_node_ips: Any, device_mode: Any, devices_per_proc: Any, args_port: int = ...): ...
def use_paddlecloud(): ...
def get_trainers_num(): ...



from __future__ import annotations

from typing import Any

from paddle.distributed.fleet.meta_optimizers.common import (
    OP_ROLE_VAR_KEY as OP_ROLE_VAR_KEY,
)
from paddle.fluid import core as core
from paddle.fluid import unique_name as unique_name
from paddle.fluid.data_feeder import check_dtype as check_dtype
from paddle.fluid.data_feeder import (
    check_variable_and_dtype as check_variable_and_dtype,
)
from paddle.fluid.framework import Parameter as Parameter
from paddle.fluid.framework import Program as Program
from paddle.fluid.framework import Variable as Variable
from paddle.fluid.framework import program_guard as program_guard

from ..dist_attribute import (
    OperatorDistributedAttribute as OperatorDistributedAttribute,
)
from ..process_group import new_process_group as new_process_group
from ..utils import (
    compute_compatible_and_update_dim_mapping as compute_compatible_and_update_dim_mapping,
)
from ..utils import compute_compatible_dim_mapping as compute_compatible_dim_mapping
from ..utils import compute_compatible_dims_mapping as compute_compatible_dims_mapping
from ..utils import is_dim_replicate as is_dim_replicate
from ..utils import is_dim_shard as is_dim_shard
from ..utils import is_valid_list_index as is_valid_list_index
from ..utils import set_dist_op_desc_original_id as set_dist_op_desc_original_id
from .common import DistributedOperatorImpl as DistributedOperatorImpl
from .common import DistributedOperatorImplContainer as DistributedOperatorImplContainer
from .common import is_parameter_related as is_parameter_related
from .common import (
    register_distributed_operator_impl as register_distributed_operator_impl,
)
from .common import (
    register_distributed_operator_impl_container as register_distributed_operator_impl_container,
)

__op_not_need_param_init__: Any

class DistributedDefault(DistributedOperatorImplContainer):
    def __init__(self, op_type: Any) -> None: ...

class DistributedDefaultImpl0(DistributedOperatorImpl):
    def __init__(self, name: Any) -> None: ...
    def is_input_compatible(self, dist_op: Any): ...
    def is_output_compatible(self, dist_op: Any): ...
    def is_auto_compatible(self, dist_op: Any): ...
    def update_dims_mapping(self, dist_op: Any): ...
    @staticmethod
    def forward(ctx: Any, *args: Any, **kwargs: Any) -> None: ...
    @staticmethod
    def backward(ctx: Any, *args: Any, **kwargs: Any) -> None: ...



from __future__ import annotations

from typing import Any

class Command:
    etcd: Any = ...
    prefix: Any = ...
    node_prefix: Any = ...
    np_path: Any = ...
    def __init__(self, server: Any, name: Any) -> None: ...
    def set_np(self, np: Any) -> None: ...
    def scale_np(self, np: Any): ...
    def clean(self) -> None: ...
    def close(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ...tensor import manipulation as manipulation
from ...tensor import math as math
from .. import Layer as Layer

class FloatFunctionalLayer(Layer):
    def __init__(self) -> None: ...

class add(FloatFunctionalLayer):
    def __init__(self) -> None: ...
    def forward(self, x: Any, y: Any, name: Optional[Any] = ...): ...

class subtract(FloatFunctionalLayer):
    def __init__(self) -> None: ...
    def forward(self, x: Any, y: Any, name: Optional[Any] = ...): ...

class multiply(FloatFunctionalLayer):
    def __init__(self) -> None: ...
    def forward(self, x: Any, y: Any, name: Optional[Any] = ...): ...

class divide(FloatFunctionalLayer):
    def __init__(self) -> None: ...
    def forward(self, x: Any, y: Any, name: Optional[Any] = ...): ...

class reshape(FloatFunctionalLayer):
    def __init__(self) -> None: ...
    def forward(self, x: Any, shape: Any, name: Optional[Any] = ...): ...

class transpose(FloatFunctionalLayer):
    def __init__(self) -> None: ...
    def forward(self, x: Any, perm: Any, name: Optional[Any] = ...): ...

class concat(FloatFunctionalLayer):
    def __init__(self) -> None: ...
    def forward(self, x: Any, axis: int = ..., name: Optional[Any] = ...): ...

class flatten(FloatFunctionalLayer):
    def __init__(self) -> None: ...
    def forward(self, x: Any, start_axis: int = ..., stop_axis: int = ..., name: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any

from paddle.distributed.fleet.utils.fs import FS

class HDFSClient(FS):
    pre_commands: Any = ...
    def __init__(self, hadoop_home: Any, configs: Any, time_out: Any = ..., sleep_inter: int = ...) -> None: ...
    def list_dirs(self, fs_path: Any): ...
    def ls_dir(self, fs_path: Any): ...
    def is_dir(self, fs_path: Any): ...
    def is_file(self, fs_path: Any): ...
    def is_exist(self, fs_path: Any): ...
    def upload(self, local_path: Any, fs_path: Any): ...
    def download(self, fs_path: Any, local_path: Any): ...
    def mkdirs(self, fs_path: Any) -> None: ...
    def mv(self, fs_src_path: Any, fs_dst_path: Any, overwrite: bool = ..., test_exists: bool = ...): ...
    def delete(self, fs_path: Any): ...
    def touch(self, fs_path: Any, exist_ok: bool = ...): ...
    def need_upload_download(self): ...



from __future__ import annotations

from typing import Any, Optional

def parameters_to_vector(parameters: Any, name: Optional[Any] = ...): ...
def vector_to_parameters(vec: Any, parameters: Any, name: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any

from paddle.fluid.data_feeder import check_dtype as check_dtype

def check_input_type(input: Any, name: Any, op_name: Any) -> None: ...
def check_initial_inverse_hessian_estimate(H0: Any): ...



from __future__ import annotations

import unittest
from typing import Any, Optional

def linear_fc(num: Any): ...
def residual_block(num: Any, quant_skip_pattern: Optional[Any] = ...): ...
def conv_net(img: Any, label: Any, quant_skip_pattern: Any): ...

class TestQuantizationTransformPass(unittest.TestCase):
    quantizable_op_and_inputs: Any = ...
    quantizable_grad_op_inputs: Any = ...
    def setUp(self) -> None: ...
    def check_program(self, program: Any) -> None: ...
    def linear_fc_quant(self, activation_quant_type: Any, weight_quantize_type: Any, for_ci: bool = ...) -> None: ...
    def test_linear_fc_quant_abs_max(self) -> None: ...
    def test_linear_fc_quant_range_abs_max(self) -> None: ...
    def test_linear_fc_quant_moving_average_abs_max(self) -> None: ...
    def residual_block_quant(
        self, activation_quant_type: Any, weight_quantize_type: Any, quantizable_op_type: Any, for_ci: bool = ...
    ) -> None: ...
    def test_residual_block_abs_max(self) -> None: ...
    def test_residual_block_range_abs_max(self) -> None: ...
    def test_residual_block_moving_average_abs_max(self) -> None: ...

class TestQuantizationFreezePass(unittest.TestCase):
    def freeze_graph(
        self,
        use_cuda: Any,
        seed: Any,
        activation_quant_type: Any,
        bias_correction: bool = ...,
        weight_quant_type: str = ...,
        for_ci: bool = ...,
        quant_skip_pattern: str = ...,
    ): ...
    def test_freeze_graph_cuda_dynamic(self) -> None: ...
    def test_freeze_graph_cpu_dynamic(self) -> None: ...
    def test_freeze_graph_cuda_static(self) -> None: ...
    def test_freeze_graph_cpu_static(self) -> None: ...

def quant_dequant_residual_block(num: Any, quant_skip_pattern: Optional[Any] = ...): ...

class TestAddQuantDequantPass(unittest.TestCase):
    def setUp(self) -> None: ...
    def check_graph(self, graph: Any, skip_pattern: Optional[Any] = ...) -> None: ...
    def residual_block_quant(
        self, quantizable_op_type: Any, skip_pattern: Optional[Any] = ..., for_ci: bool = ...
    ) -> None: ...
    def test_residual_block(self) -> None: ...
    def test_residual_block_skip_pattern(self) -> None: ...
    def test_residual_block_skip_pattern_1(self) -> None: ...

class TestQuantizationTransformPassV2(unittest.TestCase):
    quantizable_op_and_inputs: Any = ...
    quantizable_grad_op_inputs: Any = ...
    def setUp(self) -> None: ...
    def check_program(self, program: Any) -> None: ...
    def linear_fc_quant(self, activation_quant_type: Any, weight_quantize_type: Any, for_ci: bool = ...) -> None: ...
    def test_linear_fc_quant_abs_max(self) -> None: ...
    def test_linear_fc_quant_channel_wise_abs_max(self) -> None: ...
    def residual_block_quant(
        self, activation_quant_type: Any, weight_quantize_type: Any, quantizable_op_type: Any, for_ci: bool = ...
    ) -> None: ...
    def test_residual_block_abs_max(self) -> None: ...
    def test_residual_block_channel_wise_abs_max(self) -> None: ...



from __future__ import annotations

from ...fluid.layers import gather_tree as gather_tree
from ...fluid.layers import temporal_shift as temporal_shift
from .activation import celu as celu
from .activation import elu as elu
from .activation import elu_ as elu_
from .activation import gelu as gelu
from .activation import glu as glu
from .activation import gumbel_softmax as gumbel_softmax
from .activation import hardshrink as hardshrink
from .activation import hardsigmoid as hardsigmoid
from .activation import hardswish as hardswish
from .activation import hardtanh as hardtanh
from .activation import leaky_relu as leaky_relu
from .activation import log_sigmoid as log_sigmoid
from .activation import log_softmax as log_softmax
from .activation import maxout as maxout
from .activation import mish as mish
from .activation import prelu as prelu
from .activation import relu as relu
from .activation import relu6 as relu6
from .activation import relu_ as relu_
from .activation import selu as selu
from .activation import sigmoid as sigmoid
from .activation import silu as silu
from .activation import softmax as softmax
from .activation import softmax_ as softmax_
from .activation import softplus as softplus
from .activation import softshrink as softshrink
from .activation import softsign as softsign
from .activation import swish as swish
from .activation import tanh as tanh
from .activation import tanh_ as tanh_
from .activation import tanhshrink as tanhshrink
from .activation import thresholded_relu as thresholded_relu
from .common import alpha_dropout as alpha_dropout
from .common import bilinear as bilinear
from .common import class_center_sample as class_center_sample
from .common import cosine_similarity as cosine_similarity
from .common import dropout as dropout
from .common import dropout2d as dropout2d
from .common import dropout3d as dropout3d
from .common import fold as fold
from .common import interpolate as interpolate
from .common import label_smooth as label_smooth
from .common import linear as linear
from .common import pad as pad
from .common import unfold as unfold
from .common import upsample as upsample
from .common import zeropad2d as zeropad2d
from .conv import conv1d as conv1d
from .conv import conv1d_transpose as conv1d_transpose
from .conv import conv2d as conv2d
from .conv import conv2d_transpose as conv2d_transpose
from .conv import conv3d as conv3d
from .conv import conv3d_transpose as conv3d_transpose
from .extension import diag_embed as diag_embed
from .extension import sequence_mask as sequence_mask
from .input import embedding as embedding
from .input import one_hot as one_hot
from .loss import binary_cross_entropy as binary_cross_entropy
from .loss import binary_cross_entropy_with_logits as binary_cross_entropy_with_logits
from .loss import cross_entropy as cross_entropy
from .loss import ctc_loss as ctc_loss
from .loss import dice_loss as dice_loss
from .loss import hinge_embedding_loss as hinge_embedding_loss
from .loss import hsigmoid_loss as hsigmoid_loss
from .loss import kl_div as kl_div
from .loss import l1_loss as l1_loss
from .loss import log_loss as log_loss
from .loss import margin_cross_entropy as margin_cross_entropy
from .loss import margin_ranking_loss as margin_ranking_loss
from .loss import mse_loss as mse_loss
from .loss import nll_loss as nll_loss
from .loss import npair_loss as npair_loss
from .loss import sigmoid_focal_loss as sigmoid_focal_loss
from .loss import smooth_l1_loss as smooth_l1_loss
from .loss import softmax_with_cross_entropy as softmax_with_cross_entropy
from .loss import square_error_cost as square_error_cost
from .norm import batch_norm as batch_norm
from .norm import instance_norm as instance_norm
from .norm import layer_norm as layer_norm
from .norm import local_response_norm as local_response_norm
from .norm import normalize as normalize
from .pooling import adaptive_avg_pool1d as adaptive_avg_pool1d
from .pooling import adaptive_avg_pool2d as adaptive_avg_pool2d
from .pooling import adaptive_avg_pool3d as adaptive_avg_pool3d
from .pooling import adaptive_max_pool1d as adaptive_max_pool1d
from .pooling import adaptive_max_pool2d as adaptive_max_pool2d
from .pooling import adaptive_max_pool3d as adaptive_max_pool3d
from .pooling import avg_pool1d as avg_pool1d
from .pooling import avg_pool2d as avg_pool2d
from .pooling import avg_pool3d as avg_pool3d
from .pooling import max_pool1d as max_pool1d
from .pooling import max_pool2d as max_pool2d
from .pooling import max_pool3d as max_pool3d
from .pooling import max_unpool1d as max_unpool1d
from .pooling import max_unpool2d as max_unpool2d
from .pooling import max_unpool3d as max_unpool3d
from .sparse_attention import sparse_attention as sparse_attention
from .vision import affine_grid as affine_grid
from .vision import grid_sample as grid_sample
from .vision import pixel_shuffle as pixel_shuffle



from __future__ import annotations

from typing import Any

URL_PREFIX: str
CIFAR10_URL: Any
CIFAR10_MD5: str
CIFAR100_URL: Any
CIFAR100_MD5: str

def reader_creator(filename: Any, sub_name: Any, cycle: bool = ...): ...
def train100(): ...
def test100(): ...
def train10(cycle: bool = ...): ...
def test10(cycle: bool = ...): ...
def fetch() -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid import core as core
from paddle.fluid.framework import Variable as Variable
from paddle.optimizer import Optimizer

class ModelAverage(Optimizer):
    helper: Any = ...
    average_window: Any = ...
    min_average_window: Any = ...
    max_average_window: Any = ...
    type: str = ...
    apply_program: Any = ...
    restore_program: Any = ...
    def __init__(
        self,
        average_window_rate: Any,
        parameters: Optional[Any] = ...,
        min_average_window: int = ...,
        max_average_window: int = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameters: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ) -> None: ...
    def step(self) -> None: ...
    def apply(self, executor: Optional[Any] = ..., need_restore: bool = ...) -> None: ...
    def restore(self, executor: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from ...fluid.contrib.mixed_precision import (
    AutoMixedPrecisionLists as AutoMixedPrecisionLists,
)
from ...fluid.contrib.mixed_precision import CustomOpLists as CustomOpLists
from ...fluid.contrib.mixed_precision import bf16 as bf16
from ...fluid.contrib.mixed_precision import cast_model_to_fp16 as cast_model_to_fp16
from ...fluid.contrib.mixed_precision import (
    cast_parameters_to_fp16 as cast_parameters_to_fp16,
)
from ...fluid.contrib.mixed_precision import decorate as decorate
from ...fluid.contrib.mixed_precision import fp16_guard as fp16_guard



from __future__ import annotations

from typing import Any

from paddle.distributed.fleet.runtime.runtime_base import RuntimeBase
from paddle.distributed.ps.utils.public import *

class Service:
    def __init__(self) -> None: ...

class GpuService(Service):
    def __init__(self) -> None: ...

class Accessor:
    accessor_class: str = ...
    optimizer: Any = ...
    feature_dim: int = ...
    embedding_dim: int = ...
    def __init__(self) -> None: ...

class CommonAccessor(Accessor):
    table_name: str = ...
    entry: str = ...
    attrs: Any = ...
    params: Any = ...
    dims: Any = ...
    trainer_num: int = ...
    sync: bool = ...
    initializers: Any = ...
    opt_input_map: Any = ...
    opt_attr_map: Any = ...
    opt_init_map: Any = ...
    def __init__(self) -> None: ...
    def define_optimize_map(self) -> None: ...
    def parse_entry(self, varname: Any, program_id: Any, context: Any) -> None: ...
    def get_shard(self, total_dim: Any, shard_num: Any, pserver_id: Any): ...
    def get_initializer_attr(self, value_name: Any, o_startup_program: Any): ...
    table_num: Any = ...
    table_dim: Any = ...
    accessor_class: str = ...
    def parse_by_optimizer(self, ctx: Any, context: Any) -> None: ...

class Tensor:
    tensor_dict: Any = ...
    def __init__(self, tesnor_dcit: Any) -> None: ...

class Table:
    table_class: Any = ...
    shard_num: int = ...
    type: Any = ...
    accessor: Any = ...
    common: Any = ...
    tensor: Any = ...
    def __init__(self) -> None: ...

class BarrierTable(Table):
    type: Any = ...
    shard_num: int = ...
    is_heter_ps_mode: Any = ...
    role_maker: Any = ...
    idx: Any = ...
    is_sync: Any = ...
    def __init__(self, context: Any, idx: Any) -> None: ...

class TensorTable(Table):
    idx: Any = ...
    tensor_dict: Any = ...
    role_maker: Any = ...
    def __init__(self, idx: Any, tensor_dict: Any, role_maker: Any) -> None: ...

class SparseTable(Table):
    context: Any = ...
    ctx: Any = ...
    type: Any = ...
    table_class: str = ...
    accessor: Any = ...
    def __init__(self, context: Any, send_ctx: Any) -> None: ...

class GeoSparseTable(SparseTable):
    table_class: str = ...
    def __init__(self, context: Any, send_ctx: Any) -> None: ...

class DenseTable(Table):
    context: Any = ...
    ctx: Any = ...
    accessor: Any = ...
    def __init__(self, context: Any, send_ctx: Any) -> None: ...

class Server:
    def __init__(self) -> None: ...

class DownpourServer(Server):
    def __init__(self) -> None: ...

class Worker:
    def __init__(self) -> None: ...

class DownpourWorker(Worker):
    def __init__(self) -> None: ...

class fsClient:
    fs_client_param: Any = ...
    def __init__(self, fs_client_param: Any) -> None: ...

class PsDescBuilder:
    context: Any = ...
    is_sync: Any = ...
    ps_mode: Any = ...
    is_heter_ps_mode: Any = ...
    use_ps_gpu: Any = ...
    barrier_table_id: Any = ...
    send_ctx: Any = ...
    tensor_table_dict: Any = ...
    tables: Any = ...
    service: Any = ...
    fs_client: Any = ...
    ps_desc: Any = ...
    def __init__(self, context: Any) -> None: ...
    def build_worker_desc(self): ...
    sparse_table_maps: Any = ...
    def build_server_desc(self): ...

class TheOnePSRuntime(RuntimeBase):
    def __init__(self) -> None: ...
    def load_model(self, path: Any, mode: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.framework import Variable as Variable

from .dist_attribute import OperatorDistributedAttribute as OperatorDistributedAttribute
from .dist_attribute import TensorDistributedAttribute as TensorDistributedAttribute
from .dist_context import (
    get_default_distributed_context as get_default_distributed_context,
)
from .dist_op import DistributedModule as DistributedModule
from .dist_tensor import DistributedTensor as DistributedTensor

def shard_tensor(x: Any, dist_attr: Optional[Any] = ...): ...
def shard_op(op_fn: Any, dist_attr: Optional[Any] = ...): ...



from __future__ import annotations

from functools import reduce as reduce
from typing import Any, Optional

from paddle.fluid import layers as layers
from paddle.fluid.evaluator import Evaluator as Evaluator
from paddle.fluid.framework import default_startup_program as default_startup_program
from paddle.reader import ComposeNotAligned as ComposeNotAligned
from paddle.reader import buffered as buffered
from paddle.reader import cache as cache
from paddle.reader import chain as chain
from paddle.reader import compose as compose
from paddle.reader import firstn as firstn
from paddle.reader import map_readers as map_readers
from paddle.reader import multiprocess_reader as multiprocess_reader
from paddle.reader import shuffle as shuffle
from paddle.reader import xmap_readers as xmap_readers

from . import core as core
from . import dataloader as dataloader
from . import reader as reader
from . import unique_name as unique_name
from .dataloader import *
from .reader import *
from .wrapped_decorator import (
    signature_safe_contextmanager as signature_safe_contextmanager,
)

batch: Any

class _open_buffer:
    buffer: Any = ...
    def __init__(self, buffer: Any) -> None: ...
    def __enter__(self): ...

class _buffer_reader(_open_buffer):
    initial_tell: Any = ...
    def __init__(self, buffer: Any) -> None: ...
    def __exit__(self, *args: Any) -> None: ...

class _buffer_writer(_open_buffer):
    def __exit__(self, *args: Any) -> None: ...

def is_parameter(var: Any): ...
def is_persistable(var: Any): ...
def is_belong_to_optimizer(var: Any): ...
def get_program_parameter(program: Any): ...
def get_program_persistable_vars(program: Any): ...
def save_vars(
    executor: Any,
    dirname: Any,
    main_program: Optional[Any] = ...,
    vars: Optional[Any] = ...,
    predicate: Optional[Any] = ...,
    filename: Optional[Any] = ...,
): ...
def save_params(executor: Any, dirname: Any, main_program: Optional[Any] = ..., filename: Optional[Any] = ...): ...
def save_persistables(
    executor: Any, dirname: Any, main_program: Optional[Any] = ..., filename: Optional[Any] = ...
): ...
def load_vars(
    executor: Any,
    dirname: Any,
    main_program: Optional[Any] = ...,
    vars: Optional[Any] = ...,
    predicate: Optional[Any] = ...,
    filename: Optional[Any] = ...,
) -> None: ...
def load_params(
    executor: Any, dirname: Any, main_program: Optional[Any] = ..., filename: Optional[Any] = ...
) -> None: ...
def load_persistables(
    executor: Any, dirname: Any, main_program: Optional[Any] = ..., filename: Optional[Any] = ...
) -> None: ...
def prepend_feed_ops(inference_program: Any, feed_target_names: Any, feed_holder_name: str = ...) -> None: ...
def append_fetch_ops(inference_program: Any, fetch_target_names: Any, fetch_holder_name: str = ...) -> None: ...
def save_inference_model(
    dirname: Any,
    feeded_var_names: Any,
    target_vars: Any,
    executor: Any,
    main_program: Optional[Any] = ...,
    model_filename: Optional[Any] = ...,
    params_filename: Optional[Any] = ...,
    export_for_deployment: bool = ...,
    program_only: bool = ...,
    clip_extra: bool = ...,
): ...
def load_inference_model(
    dirname: Any,
    executor: Any,
    model_filename: Optional[Any] = ...,
    params_filename: Optional[Any] = ...,
    pserver_endpoints: Optional[Any] = ...,
): ...
def get_parameter_value(para: Any, executor: Any): ...
def get_parameter_value_by_name(name: Any, executor: Any, program: Optional[Any] = ...): ...
def save(program: Any, model_path: Any, protocol: int = ..., **configs: Any): ...
def load(program: Any, model_path: Any, executor: Optional[Any] = ..., var_list: Optional[Any] = ...) -> None: ...
def load_program_state(model_path: Any, var_list: Optional[Any] = ...): ...
def set_program_state(program: Any, state_dict: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.framework import ParamAttr
from paddle.nn import Layer
from typing_extensions import Literal

from ..._typing import IntSequence, Numberic, NumbericSequence, Tensor
from ...fluid.dygraph import Flatten as Flatten

class Identity(Layer):
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    def forward(self, input: Tensor) -> Tensor: ...
    __call__ = forward

class Linear(Layer):
    weight: Tensor = ...
    bias: Tensor = ...
    def __init__(
        self,
        in_features: int,
        out_features: int,
        weight_attr: Optional[ParamAttr] = ...,
        bias_attr: Optional[ParamAttr] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, input: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Upsample(Layer):
    size: Any = ...
    scale_factor: Any = ...
    mode: Any = ...
    align_corners: Any = ...
    align_mode: Any = ...
    data_format: Any = ...
    name: str = ...
    def __init__(
        self,
        size: Optional[IntSequence | Tensor] = ...,
        scale_factor: Optional[Numberic | NumbericSequence | Tensor] = ...,
        mode: Literal["linear", "bilinear", "trilinear", "nearest", "bicubic"] = ...,
        align_corners: bool = ...,
        align_mode: int = ...,
        data_format: str = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class UpsamplingNearest2D(Layer):
    size: Any = ...
    scale_factor: Any = ...
    data_format: Any = ...
    name: str = ...
    def __init__(
        self,
        size: Optional[IntSequence | Tensor] = ...,
        scale_factor: Optional[Numberic | NumbericSequence | Tensor] = ...,
        data_format: Literal["NCW", "NWC", "NCHW", "NHWC", "NCDHW", "NDHWC"] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class UpsamplingBilinear2D(Layer):
    size: Any = ...
    scale_factor: Any = ...
    data_format: Any = ...
    name: str = ...
    def __init__(
        self,
        size: Optional[IntSequence | Tensor] = ...,
        scale_factor: Optional[Numberic | NumbericSequence | Tensor] = ...,
        data_format: Literal["NCW", "NWC", "NCHW", "NHWC", "NCDHW", "NDHWC"] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Bilinear(Layer):
    weight: Tensor = ...
    bias: Tensor = ...
    def __init__(
        self,
        in1_features: int,
        in2_features: int,
        out_features: int,
        weight_attr: Optional[ParamAttr] = ...,
        bias_attr: Optional[ParamAttr] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, x1: Tensor, x2: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Dropout(Layer):
    p: Any = ...
    axis: Any = ...
    mode: Any = ...
    name: str = ...
    def __init__(
        self,
        p: float = ...,
        axis: Optional[int | IntSequence] = ...,
        mode: Literal["upscale_in_train", "downscale_in_infer"] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, input: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Dropout2D(Layer):
    p: Any = ...
    data_format: Any = ...
    name: str = ...
    def __init__(
        self,
        p: float = ...,
        data_format: Literal["NCHW", "NHWC"] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, input: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Dropout3D(Layer):
    p: Any = ...
    data_format: Any = ...
    name: str = ...
    def __init__(
        self,
        p: float = ...,
        data_format: Literal["NCDHW", "NDHWC"] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, input: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class AlphaDropout(Layer):
    p: Any = ...
    name: str = ...
    def __init__(self, p: float = ..., name: Optional[str] = ...) -> None: ...
    def forward(self, input: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Pad1D(Layer):
    def __init__(
        self,
        padding: int | IntSequence | Tensor,
        mode: Literal["constant", "reflect", "replicate", "circular"] = ...,
        value: float = ...,
        data_format: Literal["NCL", "NLC"] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Pad2D(Layer):
    def __init__(
        self,
        padding: int | IntSequence | Tensor,
        mode: Literal["constant", "reflect", "replicate", "circular"] = ...,
        value: float = ...,
        data_format: Literal["NCHW", "NHWC"] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class ZeroPad2D(Layer):
    def __init__(
        self,
        padding: int | IntSequence | Tensor,
        data_format: Literal["NCHW", "NHWC"] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Pad3D(Layer):
    def __init__(
        self,
        padding: int | IntSequence | Tensor,
        mode: Literal["constant", "reflect", "replicate", "circular"] = ...,
        value: float = ...,
        data_format: Literal["NCDHW", "NDHWC"] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class CosineSimilarity(Layer):
    def __init__(self, axis: int = ..., eps: float = ...) -> None: ...
    def forward(self, x1: Tensor, x2: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Embedding(Layer):
    weight: Any = ...
    def __init__(
        self,
        num_embeddings: int,
        embedding_dim: int,
        padding_idx: Optional[int] = ...,
        sparse: bool = ...,
        weight_attr: Optional[ParamAttr] = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Unfold(Layer):
    kernel_sizes: Any = ...
    dilations: Any = ...
    paddings: Any = ...
    strides: Any = ...
    name: str = ...
    def __init__(
        self,
        kernel_sizes: int | IntSequence,
        dilations: int = ...,
        paddings: int = ...,
        strides: int = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, input: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward

class Fold(Layer):
    output_sizes: Any = ...
    kernel_sizes: Any = ...
    dilations: Any = ...
    paddings: Any = ...
    strides: Any = ...
    name: str = ...
    def __init__(
        self,
        output_sizes: IntSequence,
        kernel_sizes: int | IntSequence,
        dilations: int | IntSequence = ...,
        paddings: int | IntSequence = ...,
        strides: int | IntSequence = ...,
        name: Optional[str] = ...,
    ) -> None: ...
    def forward(self, input: Tensor) -> Tensor: ...
    def extra_repr(self) -> Tensor: ...
    __call__ = forward



from __future__ import annotations

from typing import Any, Optional

def sparse_coo_tensor(
    indices: Any,
    values: Any,
    shape: Optional[Any] = ...,
    dtype: Optional[Any] = ...,
    place: Optional[Any] = ...,
    stop_gradient: bool = ...,
): ...
def sparse_csr_tensor(
    crows: Any,
    cols: Any,
    values: Any,
    shape: Any,
    dtype: Optional[Any] = ...,
    place: Optional[Any] = ...,
    stop_gradient: bool = ...,
): ...



from __future__ import annotations

from typing import Any, Optional

def graph_send_recv(
    x: Any,
    src_index: Any,
    dst_index: Any,
    pool_type: str = ...,
    out_size: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from typing import Any

class Distribution:
    def sample(self) -> None: ...
    def entropy(self) -> None: ...
    def kl_divergence(self, other: Any) -> None: ...
    def log_prob(self, value: Any) -> None: ...

class Uniform(Distribution):
    all_arg_is_float: bool = ...
    batch_size_unknown: bool = ...
    low: Any = ...
    high: Any = ...
    def __init__(self, low: Any, high: Any) -> None: ...
    def sample(self, shape: Any, seed: int = ...): ...
    def log_prob(self, value: Any): ...
    def entropy(self): ...

class Normal(Distribution):
    batch_size_unknown: bool = ...
    all_arg_is_float: bool = ...
    loc: Any = ...
    scale: Any = ...
    def __init__(self, loc: Any, scale: Any) -> None: ...
    def sample(self, shape: Any, seed: int = ...): ...
    def entropy(self): ...
    def log_prob(self, value: Any): ...
    def kl_divergence(self, other: Any): ...

class Categorical(Distribution):
    logits: Any = ...
    def __init__(self, logits: Any) -> None: ...
    def kl_divergence(self, other: Any): ...
    def entropy(self): ...

class MultivariateNormalDiag(Distribution):
    loc: Any = ...
    scale: Any = ...
    def __init__(self, loc: Any, scale: Any) -> None: ...
    def entropy(self): ...
    def kl_divergence(self, other: Any): ...



from __future__ import annotations

from collections import OrderedDict as OrderedDict
from typing import Any, Optional

from .status import Status as Status

class Container:
    def __init__(self, entrypoint: Any = ..., rank: int = ..., env: Any = ...) -> None: ...
    @property
    def entrypoint(self): ...
    @entrypoint.setter
    def entrypoint(self, entry: Any) -> None: ...
    @property
    def rank(self): ...
    @rank.setter
    def rank(self, r: Any) -> None: ...
    @property
    def outfile(self): ...
    @outfile.setter
    def outfile(self, out: Any) -> None: ...
    @property
    def errfile(self): ...
    @errfile.setter
    def errfile(self, err: Any) -> None: ...
    def update_env(self, env: Any = ..., **kwargs: Any) -> None: ...
    def start(self): ...
    def terminate(self, force: bool = ...): ...
    def wait(self, timeout: Optional[Any] = ...) -> None: ...
    @property
    def exit_code(self): ...
    @property
    def status(self): ...
    def logs(self, fn: Optional[Any] = ..., offset: int = ..., whence: int = ..., limit: int = ...) -> None: ...
    def tail(self, length: int = ...) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.fluid import core as core

def delete_ops(block: Any, ops: Any) -> None: ...
def find_op_by_input_arg(block: Any, arg_name: Any): ...
def find_op_by_output_arg(block: Any, arg_name: Any, reverse: bool = ...): ...



from __future__ import annotations

from typing import Any

class Collective:
    nrings: Any = ...
    endpoints: Any = ...
    current_endpoint: Any = ...
    other_endpoints: Any = ...
    nranks: Any = ...
    rank: Any = ...
    startup_program: Any = ...
    main_program: Any = ...
    op_role_key: Any = ...
    op_role_var_key: Any = ...
    def __init__(self, nrings: Any) -> None: ...
    wait_port: Any = ...
    def transpile(
        self, startup_program: Any, main_program: Any, rank: Any, endpoints: Any, current_endpoint: Any, wait_port: Any
    ) -> None: ...

class GradAllReduce(Collective):
    mode: str = ...
    def __init__(self, nrings: int = ...) -> None: ...

class LocalSGD(Collective):
    snapshot_key: str = ...
    mode: str = ...
    def __init__(self, nrings: int = ...) -> None: ...
    def snapshot_name(self, param_name: Any): ...

class SingleProcessMultiThread(GradAllReduce):
    mode: str = ...
    def __init__(self) -> None: ...

class MultiThread(GradAllReduce):
    mode: str = ...
    trans_mode: Any = ...
    fuse_grad_size_in_num: int = ...
    gpu_num: Any = ...
    def __init__(self, nrings: int = ..., trans_mode: str = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from .progressbar import ProgressBar as ProgressBar

def config_callbacks(
    callbacks: Optional[Any] = ...,
    model: Optional[Any] = ...,
    batch_size: Optional[Any] = ...,
    epochs: Optional[Any] = ...,
    steps: Optional[Any] = ...,
    log_freq: int = ...,
    verbose: int = ...,
    save_freq: int = ...,
    save_dir: Optional[Any] = ...,
    metrics: Optional[Any] = ...,
    mode: str = ...,
): ...

class CallbackList:
    callbacks: Any = ...
    params: Any = ...
    model: Any = ...
    def __init__(self, callbacks: Optional[Any] = ...) -> None: ...
    def append(self, callback: Any) -> None: ...
    def __iter__(self) -> Any: ...
    def set_params(self, params: Any) -> None: ...
    def set_model(self, model: Any) -> None: ...
    def on_begin(self, mode: Any, logs: Optional[Any] = ...) -> None: ...
    def on_end(self, mode: Any, logs: Optional[Any] = ...) -> None: ...
    def on_epoch_begin(self, epoch: Optional[Any] = ..., logs: Optional[Any] = ...) -> None: ...
    def on_epoch_end(self, epoch: Optional[Any] = ..., logs: Optional[Any] = ...) -> None: ...
    def on_batch_begin(self, mode: Any, step: Optional[Any] = ..., logs: Optional[Any] = ...) -> None: ...
    def on_batch_end(self, mode: Any, step: Optional[Any] = ..., logs: Optional[Any] = ...) -> None: ...

class Callback:
    model: Any = ...
    params: Any = ...
    def __init__(self) -> None: ...
    def set_params(self, params: Any) -> None: ...
    def set_model(self, model: Any) -> None: ...
    def on_train_begin(self, logs: Optional[Any] = ...) -> None: ...
    def on_train_end(self, logs: Optional[Any] = ...) -> None: ...
    def on_eval_begin(self, logs: Optional[Any] = ...) -> None: ...
    def on_eval_end(self, logs: Optional[Any] = ...) -> None: ...
    def on_predict_begin(self, logs: Optional[Any] = ...) -> None: ...
    def on_predict_end(self, logs: Optional[Any] = ...) -> None: ...
    def on_epoch_begin(self, epoch: Any, logs: Optional[Any] = ...) -> None: ...
    def on_epoch_end(self, epoch: Any, logs: Optional[Any] = ...) -> None: ...
    def on_train_batch_begin(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    def on_train_batch_end(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    def on_eval_batch_begin(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    def on_eval_batch_end(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    def on_predict_batch_begin(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    def on_predict_batch_end(self, step: Any, logs: Optional[Any] = ...) -> None: ...

class ProgBarLogger(Callback):
    epochs: Any = ...
    steps: Any = ...
    progbar: Any = ...
    verbose: Any = ...
    log_freq: Any = ...
    def __init__(self, log_freq: int = ..., verbose: int = ...) -> None: ...
    train_metrics: Any = ...
    def on_train_begin(self, logs: Optional[Any] = ...) -> None: ...
    epoch: Any = ...
    train_step: int = ...
    train_progbar: Any = ...
    def on_epoch_begin(self, epoch: Optional[Any] = ..., logs: Optional[Any] = ...) -> None: ...
    def on_train_batch_begin(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    def on_train_batch_end(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    def on_epoch_end(self, epoch: Any, logs: Optional[Any] = ...) -> None: ...
    eval_steps: Any = ...
    eval_metrics: Any = ...
    eval_step: int = ...
    evaled_samples: int = ...
    eval_progbar: Any = ...
    def on_eval_begin(self, logs: Optional[Any] = ...) -> None: ...
    def on_eval_batch_begin(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    def on_eval_batch_end(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    test_steps: Any = ...
    test_metrics: Any = ...
    test_step: int = ...
    tested_samples: int = ...
    test_progbar: Any = ...
    def on_predict_begin(self, logs: Optional[Any] = ...) -> None: ...
    def on_predict_batch_begin(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    def on_predict_batch_end(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    def on_eval_end(self, logs: Optional[Any] = ...) -> None: ...
    def on_predict_end(self, logs: Optional[Any] = ...) -> None: ...

class ModelCheckpoint(Callback):
    save_freq: Any = ...
    save_dir: Any = ...
    def __init__(self, save_freq: int = ..., save_dir: Optional[Any] = ...) -> None: ...
    epoch: Any = ...
    def on_epoch_begin(self, epoch: Optional[Any] = ..., logs: Optional[Any] = ...) -> None: ...
    def on_epoch_end(self, epoch: Any, logs: Optional[Any] = ...) -> None: ...
    def on_train_end(self, logs: Optional[Any] = ...) -> None: ...

class LRScheduler(Callback):
    by_step: Any = ...
    by_epoch: Any = ...
    def __init__(self, by_step: bool = ..., by_epoch: bool = ...) -> None: ...
    def on_epoch_end(self, epoch: Any, logs: Optional[Any] = ...) -> None: ...
    def on_train_batch_end(self, step: Any, logs: Optional[Any] = ...) -> None: ...

class EarlyStopping(Callback):
    monitor: Any = ...
    patience: Any = ...
    verbose: Any = ...
    baseline: Any = ...
    min_delta: Any = ...
    wait_epoch: int = ...
    best_weights: Any = ...
    stopped_epoch: int = ...
    save_best_model: Any = ...
    save_dir: Any = ...
    monitor_op: Any = ...
    def __init__(
        self,
        monitor: str = ...,
        mode: str = ...,
        patience: int = ...,
        verbose: int = ...,
        min_delta: int = ...,
        baseline: Optional[Any] = ...,
        save_best_model: bool = ...,
    ) -> None: ...
    best_value: Any = ...
    def on_train_begin(self, logs: Optional[Any] = ...) -> None: ...
    def on_eval_end(self, logs: Optional[Any] = ...) -> None: ...

class VisualDL(Callback):
    log_dir: Any = ...
    epochs: Any = ...
    steps: Any = ...
    epoch: int = ...
    def __init__(self, log_dir: Any) -> None: ...
    train_metrics: Any = ...
    train_step: int = ...
    def on_train_begin(self, logs: Optional[Any] = ...) -> None: ...
    def on_epoch_begin(self, epoch: Optional[Any] = ..., logs: Optional[Any] = ...) -> None: ...
    def on_train_batch_end(self, step: Any, logs: Optional[Any] = ...) -> None: ...
    eval_steps: Any = ...
    eval_metrics: Any = ...
    eval_step: int = ...
    evaled_samples: int = ...
    def on_eval_begin(self, logs: Optional[Any] = ...) -> None: ...
    def on_train_end(self, logs: Optional[Any] = ...) -> None: ...
    def on_eval_end(self, logs: Optional[Any] = ...) -> None: ...

class ReduceLROnPlateau(Callback):
    monitor: Any = ...
    factor: Any = ...
    min_lr: Any = ...
    min_delta: Any = ...
    patience: Any = ...
    verbose: Any = ...
    cooldown: Any = ...
    cooldown_counter: int = ...
    wait: int = ...
    best: int = ...
    mode: Any = ...
    monitor_op: Any = ...
    epoch: int = ...
    def __init__(
        self,
        monitor: str = ...,
        factor: float = ...,
        patience: int = ...,
        verbose: int = ...,
        mode: str = ...,
        min_delta: float = ...,
        cooldown: int = ...,
        min_lr: int = ...,
    ) -> None: ...
    def on_train_begin(self, logs: Optional[Any] = ...) -> None: ...
    def on_eval_end(self, logs: Optional[Any] = ...) -> None: ...
    def in_cooldown(self): ...



from __future__ import annotations

from typing import Any, Optional

class OptimizerWithMixedPrecision:
    def __init__(self, optimizer: Any, amp_lists: Any, use_pure_bf16: Any, use_bf16_guard: Any) -> None: ...
    def backward(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ): ...
    def amp_init(
        self, place: Any, scope: Optional[Any] = ..., test_program: Optional[Any] = ..., use_bf16_test: bool = ...
    ) -> None: ...
    def apply_gradients(self, params_grads: Any): ...
    def apply_optimize(self, loss: Any, startup_program: Any, params_grads: Any): ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...

def decorate_bf16(
    optimizer: Any, amp_lists: Optional[Any] = ..., use_pure_bf16: bool = ..., use_bf16_guard: Optional[Any] = ...
): ...



from __future__ import annotations

from typing import Any

from paddle.distributed.auto_parallel.process_mesh import ProcessMesh as ProcessMesh
from paddle.fluid.backward import ProgramStats

from .pass_base import PassBase as PassBase
from .pass_base import register_pass as register_pass

class RecomputeState(ProgramStats):
    var_op_deps: Any = ...
    def __init__(self, block: Any, ops: Any) -> None: ...
    def build_stats(self) -> None: ...
    def get_recompute_segments(self, checkpoints: Any): ...
    def modify_forward_desc_for_recompute(self, dist_context: Any) -> None: ...

class RecomputePass(PassBase):
    def __init__(self) -> None: ...
    def reset_op_dist_attr(self, op: Any, var_name_dict: Any) -> None: ...
    def set_op_dist_attr(self, op: Any, old_dist_attr: Any, var_name_dict: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ..fluid import core as core
from ..fluid import framework as framework
from ..fluid.framework import Variable as Variable
from ..fluid.framework import name_scope as name_scope
from .optimizer import Optimizer as Optimizer

class Adadelta(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: float = ...,
        epsilon: float = ...,
        rho: float = ...,
        parameters: Optional[Any] = ...,
        weight_decay: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...



from __future__ import annotations

from typing import Any

class TranslatorLogger:
    def __new__(cls, *args: Any, **kwargs: Any): ...
    logger_name: str = ...
    def __init__(self) -> None: ...
    @property
    def logger(self): ...
    @property
    def verbosity_level(self): ...
    @verbosity_level.setter
    def verbosity_level(self, level: Any) -> None: ...
    @property
    def transformed_code_level(self): ...
    @transformed_code_level.setter
    def transformed_code_level(self, level: Any) -> None: ...
    @property
    def need_to_echo_log_to_stdout(self): ...
    @need_to_echo_log_to_stdout.setter
    def need_to_echo_log_to_stdout(self, log_to_stdout: Any) -> None: ...
    @property
    def need_to_echo_code_to_stdout(self): ...
    @need_to_echo_code_to_stdout.setter
    def need_to_echo_code_to_stdout(self, code_to_stdout: Any) -> None: ...
    def check_level(self, level: Any): ...
    def has_code_level(self, level: Any): ...
    def has_verbosity(self, level: Any): ...
    def error(self, msg: Any, *args: Any, **kwargs: Any) -> None: ...
    def warn(self, msg: Any, *args: Any, **kwargs: Any) -> None: ...
    def log(self, level: Any, msg: Any, *args: Any, **kwargs: Any) -> None: ...
    def log_transformed_code(
        self, level: Any, ast_node: Any, transformer_name: Any, *args: Any, **kwargs: Any
    ) -> None: ...

def set_verbosity(level: int = ..., also_to_stdout: bool = ...) -> None: ...
def set_code_level(level: Any = ..., also_to_stdout: bool = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.distributed.fleet.launch_utils import logger as logger

def get_cloud_cluster(rank_table_file: Optional[Any] = ..., device_mode: Any = ..., start_port: int = ...): ...



from __future__ import annotations

from typing import Any, Optional

def sum(input: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def max(input: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def min(input: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def auc(stat_pos: Any, stat_neg: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def mae(abserr: Any, total_ins_num: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def rmse(sqrerr: Any, total_ins_num: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def mse(sqrerr: Any, total_ins_num: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...
def acc(correct: Any, total: Any, scope: Optional[Any] = ..., util: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

from . import Layer

class LSTMCell(Layer):
    def __init__(
        self,
        hidden_size: Any,
        input_size: Any,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        gate_activation: Optional[Any] = ...,
        activation: Optional[Any] = ...,
        forget_bias: float = ...,
        use_cudnn_impl: bool = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any, pre_hidden: Any, pre_cell: Any): ...

class GRUCell(Layer):
    def __init__(
        self,
        hidden_size: Any,
        input_size: Any,
        param_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        gate_activation: Optional[Any] = ...,
        activation: Optional[Any] = ...,
        use_cudnn_impl: bool = ...,
        dtype: str = ...,
    ) -> None: ...
    def forward(self, input: Any, pre_hidden: Any): ...



from __future__ import annotations

from typing import Any, Optional

from paddle import fluid as fluid

from .parameter_server_optimizer import (
    ParameterServerOptimizer as ParameterServerOptimizer,
)

class ParameterServerGraphOptimizer(ParameterServerOptimizer):
    inner_opt: Any = ...
    meta_optimizers_white_list: Any = ...
    def __init__(self, optimizer: Any) -> None: ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...



from __future__ import annotations

from typing import Any, Optional

class LearningRateDecay:
    step_num: Any = ...
    step_size: Any = ...
    dtype: Any = ...
    def __init__(self, begin: int = ..., step: int = ..., dtype: str = ...) -> None: ...
    def __call__(self): ...
    def create_lr_var(self, lr: Any): ...
    def state_dict(self): ...
    def set_state_dict(self, state_dict: Any) -> None: ...
    set_dict: Any = ...
    def step(self) -> None: ...

class PiecewiseDecay(LearningRateDecay):
    boundaries: Any = ...
    values: Any = ...
    vars: Any = ...
    def __init__(self, boundaries: Any, values: Any, begin: Any, step: int = ..., dtype: str = ...) -> None: ...
    def step(self): ...

class NaturalExpDecay(LearningRateDecay):
    learning_rate: Any = ...
    decay_steps: Any = ...
    decay_rate: Any = ...
    staircase: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        decay_steps: Any,
        decay_rate: Any,
        staircase: bool = ...,
        begin: int = ...,
        step: int = ...,
        dtype: str = ...,
    ) -> None: ...
    def step(self): ...

class ExponentialDecay(LearningRateDecay):
    learning_rate: Any = ...
    decay_steps: Any = ...
    decay_rate: Any = ...
    staircase: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        decay_steps: Any,
        decay_rate: Any,
        staircase: bool = ...,
        begin: int = ...,
        step: int = ...,
        dtype: str = ...,
    ) -> None: ...
    def step(self): ...

class InverseTimeDecay(LearningRateDecay):
    learning_rate: Any = ...
    decay_steps: Any = ...
    decay_rate: Any = ...
    staircase: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        decay_steps: Any,
        decay_rate: Any,
        staircase: bool = ...,
        begin: int = ...,
        step: int = ...,
        dtype: str = ...,
    ) -> None: ...
    def step(self): ...

class PolynomialDecay(LearningRateDecay):
    learning_rate: Any = ...
    decay_steps: Any = ...
    end_learning_rate: Any = ...
    power: Any = ...
    cycle: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        decay_steps: Any,
        end_learning_rate: float = ...,
        power: float = ...,
        cycle: bool = ...,
        begin: int = ...,
        step: int = ...,
        dtype: str = ...,
    ) -> None: ...
    def step(self): ...

class CosineDecay(LearningRateDecay):
    learning_rate: Any = ...
    step_each_epoch: Any = ...
    epochs: Any = ...
    def __init__(
        self, learning_rate: Any, step_each_epoch: Any, epochs: Any, begin: int = ..., step: int = ..., dtype: str = ...
    ) -> None: ...
    def step(self): ...

class NoamDecay(LearningRateDecay):
    learning_rate: Any = ...
    d_model: Any = ...
    warmup_steps: Any = ...
    def __init__(
        self,
        d_model: Any,
        warmup_steps: Any,
        begin: int = ...,
        step: int = ...,
        dtype: str = ...,
        learning_rate: float = ...,
    ) -> None: ...
    def step(self): ...

class LinearLrWarmup(LearningRateDecay):
    learning_rate: Any = ...
    warmup_steps: Any = ...
    start_lr: Any = ...
    lr_ratio_before_warmup: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        warmup_steps: Any,
        start_lr: Any,
        end_lr: Any,
        begin: int = ...,
        step: int = ...,
        dtype: str = ...,
    ) -> None: ...
    def step(self): ...

class ReduceLROnPlateau(LearningRateDecay):
    mode: Any = ...
    decay_rate: Any = ...
    threshold_mode: Any = ...
    learning_rate: Any = ...
    verbose: Any = ...
    patience: Any = ...
    threshold: Any = ...
    cooldown: Any = ...
    min_lr: Any = ...
    eps: Any = ...
    cooldown_counter: int = ...
    best_loss: Any = ...
    num_bad_epochs: int = ...
    epoch_num: int = ...
    def __init__(
        self,
        learning_rate: Any,
        mode: str = ...,
        decay_rate: float = ...,
        patience: int = ...,
        verbose: bool = ...,
        threshold: float = ...,
        threshold_mode: str = ...,
        cooldown: int = ...,
        min_lr: int = ...,
        eps: float = ...,
        dtype: str = ...,
    ) -> None: ...
    def __call__(self): ...
    def step(self, loss: Any) -> None: ...

class _LearningRateEpochDecay(LearningRateDecay):
    base_lr: Any = ...
    epoch_num: int = ...
    dtype: Any = ...
    learning_rate: Any = ...
    def __init__(self, learning_rate: Any, dtype: Optional[Any] = ...) -> None: ...
    def __call__(self): ...
    def epoch(self, epoch: Optional[Any] = ...) -> None: ...
    def get_lr(self) -> None: ...

class StepDecay(_LearningRateEpochDecay):
    step_size: Any = ...
    decay_rate: Any = ...
    def __init__(self, learning_rate: Any, step_size: Any, decay_rate: float = ...) -> None: ...
    def get_lr(self): ...

class MultiStepDecay(_LearningRateEpochDecay):
    milestones: Any = ...
    decay_rate: Any = ...
    def __init__(self, learning_rate: Any, milestones: Any, decay_rate: float = ...) -> None: ...
    def get_lr(self): ...

class LambdaDecay(_LearningRateEpochDecay):
    lr_lambda: Any = ...
    def __init__(self, learning_rate: Any, lr_lambda: Any) -> None: ...
    def get_lr(self): ...



from __future__ import annotations

import multiprocessing
from typing import Any

fork_context = multiprocessing

def cache(reader: Any): ...
def map_readers(func: Any, *readers: Any): ...
def shuffle(reader: Any, buf_size: Any): ...
def chain(*readers: Any): ...

class ComposeNotAligned(ValueError): ...

def compose(*readers: Any, **kwargs: Any): ...
def buffered(reader: Any, size: Any): ...
def firstn(reader: Any, n: Any): ...

class XmapEndSignal: ...

def xmap_readers(mapper: Any, reader: Any, process_num: Any, buffer_size: Any, order: bool = ...): ...
def multiprocess_reader(readers: Any, use_pipe: bool = ..., queue_size: int = ...): ...



from __future__ import annotations

from ...ps.the_one_ps import TheOnePSRuntime as TheOnePSRuntime
from ..runtime.collective_runtime import CollectiveRuntime as CollectiveRuntime
from ..runtime.parameter_server_runtime import (
    ParameterServerRuntime as ParameterServerRuntime,
)

class RuntimeFactory:
    def __init__(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ...fluid.data_feeder import check_type as check_type
from ...fluid.initializer import NumpyArrayInitializer as NumpyArrayInitializer

class Assign(NumpyArrayInitializer):
    def __init__(self, value: Any, name: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    cast_bool_if_necessary as cast_bool_if_necessary,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    choose_shape_attr_or_api as choose_shape_attr_or_api,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_assert as convert_assert,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_ifelse as convert_ifelse,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_len as convert_len,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_logical_and as convert_logical_and,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_logical_not as convert_logical_not,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_logical_or as convert_logical_or,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_pop as convert_pop,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_print as convert_print,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_shape_compare as convert_shape_compare,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_var_dtype as convert_var_dtype,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_var_shape as convert_var_shape,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_var_shape_simple as convert_var_shape_simple,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    convert_while_loop as convert_while_loop,
)
from ...fluid.dygraph.dygraph_to_static.convert_operators import (
    eval_if_exist_else_none as eval_if_exist_else_none,
)



from __future__ import annotations

from typing import Any

from ... import Tensor, nn

class MakeFireConv(nn.Layer):
    def __init__(self, input_channels: Any, output_channels: Any, filter_size: Any, padding: int = ...) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class MakeFire(nn.Layer):
    def __init__(
        self, input_channels: Any, squeeze_channels: Any, expand1x1_channels: Any, expand3x3_channels: Any
    ) -> None: ...
    def forward(self, inputs: Any) -> Tensor: ...

class SqueezeNet(nn.Layer):
    def __init__(
        self,
        version: Any,
        num_classes: int = ...,
        with_pool: bool = ...,
    ) -> None: ...
    def forward(self, inputs: Tensor) -> Tensor: ...
    __call__ = forward

def squeezenet1_0(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> SqueezeNet: ...
def squeezenet1_1(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> SqueezeNet: ...



from __future__ import annotations

from .functional_layers import FloatFunctionalLayer as FloatFunctionalLayer
from .functional_layers import add as add
from .functional_layers import concat as concat
from .functional_layers import divide as divide
from .functional_layers import flatten as flatten
from .functional_layers import multiply as multiply
from .functional_layers import reshape as reshape
from .functional_layers import subtract as subtract
from .functional_layers import transpose as transpose
from .quant_layers import QuantStub as QuantStub



from __future__ import annotations

from collections import OrderedDict as OrderedDict
from typing import Any

from paddle.fluid import unique_name as unique_name
from paddle.fluid.framework import program_guard as program_guard

from .pass_base import PassBase as PassBase
from .pass_base import PassType as PassType
from .pass_base import register_pass as register_pass

world_process_group: Any

def parse_program(
    main_program: Any, startup_program: Any, params_grads: Any, k_steps: Any, avg: Any, dist_context: Any
) -> None: ...

class GradientMergePass(PassBase):
    def __init__(self) -> None: ...



from __future__ import annotations

from typing import Any

from .device import Device as Device

class Node:
    device: Any = ...
    ip: Any = ...
    free_ports: Any = ...
    def __init__(self) -> None: ...
    hostname: Any = ...
    def get_host_ip(self): ...
    def get_free_ports(self, n: int = ...): ...
    def get_ports_occupied(self): ...
    def get_free_port(self): ...
    @classmethod
    def is_server_ready(cls, ip: Any, port: Any): ...



from __future__ import annotations

from typing import Any, Optional

class BaseErrorClipAttr: ...

class ErrorClipByValue(BaseErrorClipAttr):
    max: Any = ...
    min: Any = ...
    def __init__(self, max: Any, min: Optional[Any] = ...) -> None: ...

class ClipGradBase:
    def __init__(self) -> None: ...
    def __call__(self, params_grads: Any): ...

class ClipGradByValue(ClipGradBase):
    max: Any = ...
    min: Any = ...
    def __init__(self, max: Any, min: Optional[Any] = ...) -> None: ...

class ClipGradByNorm(ClipGradBase):
    clip_norm: Any = ...
    def __init__(self, clip_norm: Any) -> None: ...

class ClipGradByGlobalNorm(ClipGradBase):
    clip_norm: Any = ...
    group_name: Any = ...
    auto_skip_clip: Any = ...
    def __init__(self, clip_norm: Any, group_name: str = ..., auto_skip_clip: bool = ...) -> None: ...

def set_gradient_clip(clip: Any, param_list: Optional[Any] = ..., program: Optional[Any] = ...) -> None: ...

GradientClipBase = ClipGradBase
GradientClipByValue = ClipGradByValue
GradientClipByNorm = ClipGradByNorm
GradientClipByGlobalNorm = ClipGradByGlobalNorm



from __future__ import annotations

from typing import Any, Optional

ExecutionStrategy: Any
BuildStrategy: Any

class CompiledProgram:
    def __init__(self, program_or_graph: Any, build_strategy: Optional[Any] = ...) -> None: ...
    def with_data_parallel(
        self,
        loss_name: Optional[Any] = ...,
        build_strategy: Optional[Any] = ...,
        exec_strategy: Optional[Any] = ...,
        share_vars_from: Optional[Any] = ...,
        places: Optional[Any] = ...,
    ): ...

class IpuStrategy:
    has_custom_ops: bool = ...
    custom_op_names: Any = ...
    def __init__(self) -> None: ...
    def set_graph_config(
        self, num_ipus: int = ..., is_training: bool = ..., micro_batch_size: int = ..., enable_manual_shard: bool = ...
    ) -> None: ...
    def set_pipelining_config(
        self,
        enable_pipelining: bool = ...,
        batches_per_step: int = ...,
        enable_gradient_accumulation: bool = ...,
        accumulation_factor: int = ...,
    ) -> None: ...
    def set_precision_config(self, enable_fp16: bool = ...) -> None: ...
    def add_custom_op(
        self, paddle_op: Any, popart_op: Optional[Any] = ..., domain: str = ..., version: int = ...
    ) -> None: ...
    def set_options(self, options: Any) -> None: ...
    def get_option(self, option: Any): ...
    def enable_pattern(self, pattern: Any) -> None: ...
    def disable_pattern(self, pattern: Any) -> None: ...
    @property
    def num_ipus(self): ...
    @property
    def is_training(self): ...
    @property
    def enable_pipelining(self): ...
    @property
    def enable_fp16(self): ...

class IpuCompiledProgram:
    def __init__(
        self, program: Optional[Any] = ..., scope: Optional[Any] = ..., ipu_strategy: Optional[Any] = ...
    ) -> None: ...
    def compile(self, feed_list: Any, fetch_list: Any): ...



from __future__ import annotations

from typing import Any

from paddle.distribution import exponential_family

class Beta(exponential_family.ExponentialFamily):
    def __init__(self, alpha: Any, beta: Any) -> None: ...
    @property
    def mean(self): ...
    @property
    def variance(self): ...
    def prob(self, value: Any): ...
    def log_prob(self, value: Any): ...
    def sample(self, shape: Any = ...): ...
    def entropy(self): ...



from __future__ import annotations

from .pass_base import CPPPassWrapper as CPPPassWrapper
from .pass_base import PassType as PassType
from .pass_base import register_pass as register_pass

class FuseElementwiseAddActPass(CPPPassWrapper):
    def __init__(self) -> None: ...
    @property
    def cpp_name(self): ...

class FuseBatchNormActPass(CPPPassWrapper):
    def __init__(self) -> None: ...
    @property
    def cpp_name(self): ...

class FuseBatchNormAddActPass(CPPPassWrapper):
    def __init__(self) -> None: ...
    @property
    def cpp_name(self): ...

class FuseReluDepthwiseConvPass(CPPPassWrapper):
    def __init__(self) -> None: ...
    @property
    def cpp_name(self): ...

class FuseOptimizerPass(CPPPassWrapper):
    def __init__(self) -> None: ...
    @property
    def cpp_name(self): ...

class InplaceAddtoOpPass(CPPPassWrapper):
    def __init__(self) -> None: ...
    @property
    def cpp_name(self): ...



from __future__ import annotations

import unittest
from typing import Any

class TestQuant2Int8MkldnnPassMul(unittest.TestCase):
    def op_name(self): ...
    scope: Any = ...
    place: Any = ...
    dtype: Any = ...
    use_mkldnn: bool = ...
    quantized_ops: Any = ...
    mul_input_size: Any = ...
    mul_weights_size: Any = ...
    mul_output_size: Any = ...
    mul_input: Any = ...
    mul_weights: Any = ...
    mul_weights_bad: Any = ...
    mul_output: Any = ...
    mul_output_scale: Any = ...
    variables_mul: Any = ...
    def setUp(self) -> None: ...
    def prepare_program_mul(self, program: Any) -> None: ...
    def test_dequantize_op_weights(self) -> None: ...

class TestQuant2Int8MkldnnPassMatmulV2(TestQuant2Int8MkldnnPassMul):
    def op_name(self): ...

class TestQuant2Int8MkldnnPassConv2D(unittest.TestCase):
    scope: Any = ...
    place: Any = ...
    dtype: Any = ...
    use_cudnn: bool = ...
    use_mkldnn: bool = ...
    data_format: str = ...
    pad: Any = ...
    stride: Any = ...
    dilations: Any = ...
    groups: int = ...
    input_size: Any = ...
    filter_size: Any = ...
    filter_size2: Any = ...
    conv_output_size: Any = ...
    conv_output2_size: Any = ...
    input: Any = ...
    filter: Any = ...
    filter2: Any = ...
    conv_output: Any = ...
    conv_output2: Any = ...
    quantized_ops: str = ...
    variables: Any = ...
    def setUp(self) -> None: ...
    def prepare_program_conv2d(self, program: Any) -> None: ...
    def remove_fuse_activation_attribute(self, graph: Any): ...
    def check_graph_before_pass(self, graph: Any) -> None: ...
    def check_graph_after_pass(self, graph: Any) -> None: ...
    def test_quant_update_activation(self) -> None: ...

    class TestQuant2Int8MkldnnPassNearestInterp(unittest.TestCase):
        def op_name(self): ...
        scope: Any = ...
        place: Any = ...
        dtype: Any = ...
        use_cudnn: bool = ...
        use_mkldnn: bool = ...
        data_format: str = ...
        pad: Any = ...
        stride: Any = ...
        dilations: Any = ...
        groups: int = ...
        input_size: Any = ...
        filter_size: Any = ...
        conv_output_size: Any = ...
        input: Any = ...
        filter: Any = ...
        conv_output: Any = ...
        out_h: int = ...
        out_w: int = ...
        scale: float = ...
        interp_method: str = ...
        data_layout: str = ...
        nearest_interp_output_size: Any = ...
        nearest_interp_output: Any = ...
        dropout_prob: float = ...
        dropout_out: Any = ...
        dropout_mask: Any = ...
        quantized_ops: Any = ...
        variables: Any = ...
        def setUp(self) -> None: ...
        def prepare_program(self, program: Any) -> None: ...
        def check_graph_after_pass(self, graph: Any) -> None: ...
        def test_quant_update_activation(self) -> None: ...

    class TestQuant2Int8MkldnnPassNearestInterpV2(unittest.TestCase):
        def op_name(self): ...



from __future__ import annotations

from typing import Any

from .. import core as core
from . import collective as collective

OpRole: Any

class AscendTranspiler(collective.Collective):
    nrings: int = ...
    def __init__(self, startup_program: Any, main_program: Any) -> None: ...
    def transpile(self) -> None: ...



from __future__ import annotations

from .layer.fused_transformer import FusedFeedForward as FusedFeedForward
from .layer.fused_transformer import FusedMultiHeadAttention as FusedMultiHeadAttention
from .layer.fused_transformer import FusedMultiTransformer as FusedMultiTransformer
from .layer.fused_transformer import (
    FusedTransformerEncoderLayer as FusedTransformerEncoderLayer,
)



from __future__ import annotations

from typing import Any, Optional

from paddle.nn import Layer

class ReLU(Layer):
    def __init__(self, name: Optional[Any] = ...) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.dygraph import layers

def prepare_context(strategy: Optional[Any] = ...): ...

class ParallelEnv:
    def __init__(self) -> None: ...
    @property
    def rank(self): ...
    @property
    def world_size(self): ...
    @property
    def device_id(self): ...
    @property
    def current_endpoint(self): ...
    @property
    def trainer_endpoints(self): ...
    @property
    def nrings(self): ...
    local_rank: Any = ...
    nranks: Any = ...
    dev_id: Any = ...

Env = ParallelEnv

class DataParallel(layers.Layer):
    find_unused_parameters: Any = ...
    grad_need_sync: bool = ...
    group: Any = ...
    var_dtype: Any = ...
    comm_buffer_size: Any = ...
    last_comm_buffer_size: Any = ...
    def __init__(
        self,
        layers: Any,
        strategy: Optional[Any] = ...,
        comm_buffer_size: int = ...,
        last_comm_buffer_size: int = ...,
        find_unused_parameters: bool = ...,
        group: Optional[Any] = ...,
    ) -> None: ...
    group_indices: Any = ...
    def init_reducer(self): ...
    def no_sync(self) -> None: ...
    def forward(self, *inputs: Any, **kwargs: Any): ...
    def scale_loss(self, loss: Any): ...
    def apply_collective_grads(self) -> None: ...
    def state_dict(
        self, destination: Optional[Any] = ..., include_sublayers: bool = ..., structured_name_prefix: str = ...
    ): ...
    def set_state_dict(self, state_dict: Any, use_structured_name: bool = ...) -> None: ...
    set_dict: Any = ...
    load_dict: Any = ...



from __future__ import annotations

from .cpp_extension import CppExtension as CppExtension
from .cpp_extension import CUDAExtension as CUDAExtension
from .cpp_extension import load as load
from .cpp_extension import setup as setup
from .extension_utils import get_build_directory as get_build_directory



from __future__ import annotations

from ast import NodeTransformer as NodeTransformer
from ast import NodeVisitor as NodeVisitor
from ast import dump as dump
from ast import iter_fields as iter_fields

from .gast import *



from __future__ import annotations

from typing import Any, Optional

from ...fluid.initializer import Initializer

class Dirac(Initializer):
    def __init__(self, groups: int = ..., name: Optional[Any] = ...) -> None: ...
    def __call__(self, var: Any, block: Optional[Any] = ...): ...



from __future__ import annotations

import collections
from collections.abc import Sequence
from typing import Any, Optional

from typing_extensions import Literal

from ..._typing import NumbericSequence

class Compose:
    transforms: Any = ...
    def __init__(self, transforms: Any) -> None: ...
    def __call__(self, data: Any): ...

class BaseTransform:
    keys: Any = ...
    params: Any = ...
    def __init__(self, keys: Optional[Any] = ...) -> None: ...
    def __call__(self, inputs: Any): ...

class ToTensor(BaseTransform):
    data_format: Any = ...
    def __init__(self, data_format: str = ..., keys: Optional[Any] = ...) -> None: ...

class Resize(BaseTransform):
    size: Any = ...
    interpolation: Any = ...
    def __init__(self, size: Any, interpolation: str = ..., keys: Optional[Any] = ...) -> None: ...

class RandomResizedCrop(BaseTransform):
    size: Any = ...
    scale: Any = ...
    ratio: Any = ...
    interpolation: Any = ...
    def __init__(
        self, size: Any, scale: Any = ..., ratio: Any = ..., interpolation: str = ..., keys: Optional[Any] = ...
    ) -> None: ...

class CenterCrop(BaseTransform):
    size: Any = ...
    def __init__(self, size: Any, keys: Optional[Any] = ...) -> None: ...

class RandomHorizontalFlip(BaseTransform):
    prob: Any = ...
    def __init__(self, prob: float = ..., keys: Optional[Any] = ...) -> None: ...

class RandomVerticalFlip(BaseTransform):
    prob: Any = ...
    def __init__(self, prob: float = ..., keys: Optional[Any] = ...) -> None: ...

class Normalize(BaseTransform):
    mean: Any = ...
    std: Any = ...
    data_format: Any = ...
    to_rgb: Any = ...
    def __init__(
        self,
        mean: NumbericSequence = ...,
        std: NumbericSequence = ...,
        data_format: Literal["HWC", "CHW"] = ...,
        to_rgb: bool = ...,
        keys: Optional[Sequence[str]] = ...,
    ) -> None: ...

class Transpose(BaseTransform):
    order: Any = ...
    def __init__(self, order: Any = ..., keys: Optional[Any] = ...) -> None: ...

class BrightnessTransform(BaseTransform):
    value: Any = ...
    def __init__(self, value: Any, keys: Optional[Any] = ...) -> None: ...

class ContrastTransform(BaseTransform):
    value: Any = ...
    def __init__(self, value: Any, keys: Optional[Any] = ...) -> None: ...

class SaturationTransform(BaseTransform):
    value: Any = ...
    def __init__(self, value: Any, keys: Optional[Any] = ...) -> None: ...

class HueTransform(BaseTransform):
    value: Any = ...
    def __init__(self, value: Any, keys: Optional[Any] = ...) -> None: ...

class ColorJitter(BaseTransform):
    brightness: Any = ...
    contrast: Any = ...
    saturation: Any = ...
    hue: Any = ...
    def __init__(
        self,
        brightness: int = ...,
        contrast: int = ...,
        saturation: int = ...,
        hue: int = ...,
        keys: Optional[Any] = ...,
    ) -> None: ...

class RandomCrop(BaseTransform):
    size: Any = ...
    padding: Any = ...
    pad_if_needed: Any = ...
    fill: Any = ...
    padding_mode: Any = ...
    def __init__(
        self,
        size: Any,
        padding: Optional[Any] = ...,
        pad_if_needed: bool = ...,
        fill: int = ...,
        padding_mode: str = ...,
        keys: Optional[Any] = ...,
    ) -> None: ...

class Pad(BaseTransform):
    padding: Any = ...
    fill: Any = ...
    padding_mode: Any = ...
    def __init__(self, padding: Any, fill: int = ..., padding_mode: str = ..., keys: Optional[Any] = ...) -> None: ...

class RandomRotation(BaseTransform):
    degrees: Any = ...
    interpolation: Any = ...
    expand: Any = ...
    center: Any = ...
    fill: Any = ...
    def __init__(
        self,
        degrees: Any,
        interpolation: str = ...,
        expand: bool = ...,
        center: Optional[Any] = ...,
        fill: int = ...,
        keys: Optional[Any] = ...,
    ) -> None: ...

class Grayscale(BaseTransform):
    num_output_channels: Any = ...
    def __init__(self, num_output_channels: int = ..., keys: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from . import core as core

def get_var_and_memory_size(block: Any, var_name: Any, batch_size: Optional[Any] = ...): ...
def pre_allocate_memory(size: Any, place: Any) -> None: ...
def get_max_memory_info(program: Any, batch_size: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

from .cost_model import estimate_cost as estimate_cost
from .dist_attribute import OperatorDistributedAttribute as OperatorDistributedAttribute
from .dist_attribute import TensorDistributedAttribute as TensorDistributedAttribute
from .dist_context import DistributedContext as DistributedContext
from .dist_context import DistributedOperatorContext as DistributedOperatorContext
from .dist_op import DistributedOperator as DistributedOperator
from .operators.common import (
    get_distributed_operator_impl_container as get_distributed_operator_impl_container,
)
from .operators.common import is_elementwise_op as is_elementwise_op
from .process_group import ProcessGroup as ProcessGroup
from .process_group import get_process_group as get_process_group
from .utils import get_all_distributed_main_program as get_all_distributed_main_program
from .utils import (
    update_op_dims_mapping_by_default_dist_impl as update_op_dims_mapping_by_default_dist_impl,
)
from .utils import (
    update_op_dims_mapping_by_elementwise_like_dist_impl as update_op_dims_mapping_by_elementwise_like_dist_impl,
)

class PlanFilter:
    @staticmethod
    def check_dims_mapping_for_tensor(process_mesh_topology: Any, tensor_shape: Any, dims_mapping: Any): ...
    @staticmethod
    def check_dims_mapping_for_op(op: Any, op_dist_attr: Any, vars: Any): ...
    @staticmethod
    def check_dims_mapping_for_special_op(op: Any, op_dist_attr: Any, vars: Any): ...

class PlanSpace:
    not_enum_ops: Any = ...
    special_vars: Any = ...
    @staticmethod
    def enum_process_mesh_topology(processes: Any): ...
    @staticmethod
    def enum_valid_dist_attr_for_program(program: Any, process_mesh_topology: Any, is_pipeline: bool = ...): ...

class SearchAlgorithm:
    def __init__(self, name: Any) -> None: ...
    @property
    def name(self) -> None: ...
    def search(self) -> None: ...

class MCMC(SearchAlgorithm):
    def __init__(self, serial_program_info: Any, parallelizer: Any, max_search_times: int = ...) -> None: ...
    @property
    def serial_program_info(self): ...
    @property
    def parallelizer(self): ...
    @property
    def max_search_times(self): ...
    def make_special_op_unshard(
        self, op: Any, ops: Any, vars: Any, dist_context: Any, valid_dist_attr_dict: Any
    ) -> None: ...
    def init_program(
        self, valid_dist_attr_dict: Any, program: Any, pipeline_process_meshes: Any, global_process_mesh: Any
    ): ...
    def estimate_searched_strategy_cost(self, dist_context: Any, pipeline_process_meshes: Optional[Any] = ...): ...
    def set_tensor_dist_attr(self, op: Any, op_dist_attr: Any, vars: Any, dist_context: Any) -> None: ...
    def change_process_mesh(self, op: Any, changed_process_mesh: Any, vars: Any, dist_context: Any) -> None: ...
    def search_once(
        self, program: Any, valid_dist_attr_dict: Any, dist_context: Any, pipeline_process_meshes: Optional[Any] = ...
    ): ...
    def search(self): ...

class Planner:
    def __init__(self, serial_program_info: Any, parallelizer: Any, algorithm_config: Optional[Any] = ...) -> None: ...
    @property
    def serial_program_info(self): ...
    @property
    def algorithm_config(self): ...
    @property
    def algorithm_searcher(self): ...
    @property
    def parallelizer(self): ...
    def create_algorithm_searcher(self, algorithm_config: Any): ...
    def search(self): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.utils import gast

TRUE_FUNC_PREFIX: str
FALSE_FUNC_PREFIX: str

class IfElseTransformer(gast.NodeTransformer):
    root: Any = ...
    static_analysis_visitor: Any = ...
    def __init__(self, wrapper_root: Any) -> None: ...
    def transform(self) -> None: ...
    def visit_If(self, node: Any): ...
    def visit_Call(self, node: Any): ...
    def visit_IfExp(self, node: Any): ...

class NameVisitor(gast.NodeVisitor):
    after_node: Any = ...
    end_node: Any = ...
    name_ids: Any = ...
    ancestor_nodes: Any = ...
    def __init__(self, after_node: Optional[Any] = ..., end_node: Optional[Any] = ...) -> None: ...
    def visit(self, node: Any): ...
    def visit_If(self, node: Any) -> None: ...
    def visit_Attribute(self, node: Any) -> None: ...
    def visit_Name(self, node: Any) -> None: ...
    def visit_Assign(self, node: Any) -> None: ...
    def visit_FunctionDef(self, node: Any) -> None: ...

def get_name_ids(nodes: Any, after_node: Optional[Any] = ..., end_node: Optional[Any] = ...): ...
def parse_cond_args(
    parent_ids_dict: Any, var_ids_dict: Any, modified_ids_dict: Optional[Any] = ..., ctx: Any = ...
): ...
def parse_cond_return(parent_vars_dict: Any, if_vars_dict: Any, else_vars_dict: Any, after_ifelse_vars_dict: Any): ...
def transform_if_else(node: Any, root: Any): ...
def create_convert_ifelse_node(
    return_name_ids: Any, pred: Any, true_func: Any, false_func: Any, is_if_expr: bool = ...
): ...



from __future__ import annotations

from typing import Any

def gloo_init_parallel_env(rank_id: Any, rank_num: Any, server_endpoint: Any) -> None: ...
def gloo_barrier() -> None: ...
def gloo_release() -> None: ...



from __future__ import annotations

from ...fluid.contrib.sparsity import calculate_density as calculate_density
from ...fluid.contrib.sparsity import decorate as decorate
from ...fluid.contrib.sparsity import prune_model as prune_model
from ...fluid.contrib.sparsity import reset_excluded_layers as reset_excluded_layers
from ...fluid.contrib.sparsity import set_excluded_layers as set_excluded_layers



from __future__ import annotations

from paddle.distribution import distribution
from paddle.fluid.framework import in_dygraph_mode as in_dygraph_mode

class ExponentialFamily(distribution.Distribution):
    def entropy(self): ...



from __future__ import annotations

from typing import Any, Optional

class QuantizationTransformPass:
    create_var_map: Any = ...
    create_op_map: Any = ...
    def __init__(
        self,
        scope: Optional[Any] = ...,
        place: Optional[Any] = ...,
        weight_bits: int = ...,
        activation_bits: int = ...,
        activation_quantize_type: str = ...,
        weight_quantize_type: str = ...,
        window_size: int = ...,
        moving_rate: float = ...,
        skip_pattern: Any = ...,
        quantizable_op_type: Any = ...,
        weight_quantize_func: Optional[Any] = ...,
        act_quantize_func: Optional[Any] = ...,
        weight_preprocess_func: Optional[Any] = ...,
        act_preprocess_func: Optional[Any] = ...,
        optimizer_func: Optional[Any] = ...,
        executor: Optional[Any] = ...,
    ) -> None: ...
    def apply(self, graph: Any): ...

class QuantizationFreezePass:
    def __init__(
        self,
        scope: Any,
        place: Any,
        bias_correction: bool = ...,
        weight_bits: int = ...,
        activation_bits: int = ...,
        round_type: str = ...,
        weight_quantize_type: str = ...,
        quantizable_op_type: Optional[Any] = ...,
    ) -> None: ...
    def apply(self, graph: Any): ...

class ConvertToInt8Pass:
    def __init__(self, scope: Any, place: Any, quantizable_op_type: Optional[Any] = ...) -> None: ...
    def apply(self, graph: Any): ...

class TransformForMobilePass:
    def __init__(self) -> None: ...
    def apply(self, graph: Any): ...

class OutScaleForTrainingPass:
    def __init__(self, scope: Optional[Any] = ..., place: Optional[Any] = ..., moving_rate: float = ...) -> None: ...
    def apply(self, graph: Any): ...

class OutScaleForInferencePass:
    def __init__(self, scope: Optional[Any] = ...) -> None: ...
    def apply(self, graph: Any): ...

class AddQuantDequantPass:
    def __init__(
        self,
        scope: Optional[Any] = ...,
        place: Optional[Any] = ...,
        moving_rate: float = ...,
        quant_bits: int = ...,
        skip_pattern: Any = ...,
        quantizable_op_type: Any = ...,
        is_full_quantized: bool = ...,
    ) -> None: ...
    def apply(self, graph: Any): ...

class InsertQuantizeLinear:
    quant_bits: Any = ...
    quant_axis: Any = ...
    channel_wise: Any = ...
    def __init__(
        self,
        place: Any,
        scope: Any,
        quant_bits: int = ...,
        quant_axis: int = ...,
        channel_wise: bool = ...,
        is_test: bool = ...,
    ) -> None: ...
    def insert_quant_op(self, graph: Any, var_node: Any): ...
    def insert_dequant_op(self, graph: Any, var_node: Any, scale_var_node: Any): ...

class QuantizationTransformPassV2:
    create_var_map: Any = ...
    create_op_map: Any = ...
    dequantized_vars: Any = ...
    persistable_vars: Any = ...
    processed_vars: Any = ...
    def __init__(
        self,
        scope: Optional[Any] = ...,
        place: Optional[Any] = ...,
        weight_bits: int = ...,
        activation_bits: int = ...,
        activation_quantize_type: str = ...,
        weight_quantize_type: str = ...,
        window_size: int = ...,
        moving_rate: float = ...,
        skip_pattern: Any = ...,
        quantizable_op_type: Any = ...,
        weight_quantize_func: Optional[Any] = ...,
        act_quantize_func: Optional[Any] = ...,
        weight_preprocess_func: Optional[Any] = ...,
        act_preprocess_func: Optional[Any] = ...,
        optimizer_func: Optional[Any] = ...,
        executor: Optional[Any] = ...,
    ) -> None: ...
    def apply(self, graph: Any): ...

class AddQuantDequantPassV2:
    persistable_vars: Any = ...
    def __init__(
        self,
        scope: Optional[Any] = ...,
        place: Optional[Any] = ...,
        moving_rate: float = ...,
        quant_bits: int = ...,
        skip_pattern: Any = ...,
        quantizable_op_type: Any = ...,
        is_full_quantized: bool = ...,
    ) -> None: ...
    def apply(self, graph: Any): ...

class ReplaceFakeQuantDequantPass:
    def __init__(self, scope: Any, place: Any) -> None: ...
    def apply(self, graph: Any): ...

class QuantWeightPass:
    def __init__(
        self, scope: Any, place: Any, bias_correction: bool = ..., quant_bits: int = ..., save_int_weight: bool = ...
    ) -> None: ...
    def apply(self, graph: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.optimizer import Optimizer

class Momentum(Optimizer):
    type: str = ...
    def __init__(
        self,
        learning_rate: Any,
        momentum: Any,
        parameter_list: Optional[Any] = ...,
        use_nesterov: bool = ...,
        regularization: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        multi_precision: bool = ...,
        rescale_grad: float = ...,
        name: Optional[Any] = ...,
    ): ...



from __future__ import annotations

from . import callbacks as callbacks
from . import hub as hub
from . import logger as logger
from . import progressbar as progressbar
from . import static_flops as static_flops
from .dynamic_flops import flops as flops
from .model import Model as Model
from .model_summary import summary as summary



from __future__ import annotations

from typing import Any

class LayerInfo:
    layer: Any = ...
    input_names: Any = ...
    weight_names: Any = ...
    output_names: Any = ...
    def __init__(self, layer: Any, input_names: Any, weight_names: Any, output_names: Any) -> None: ...

class PTQRegistry:
    supported_layers_map: Any = ...
    registered_layers_map: Any = ...
    is_inited: bool = ...
    def __init__(self) -> None: ...
    @classmethod
    def is_supported_layer(cls, layer: Any): ...
    @classmethod
    def is_registered_layer(cls, layer: Any): ...
    @classmethod
    def is_simulated_quant_layer(cls, layer: Any): ...
    @classmethod
    def layer_info(cls, layer: Any): ...



from __future__ import annotations

from paddle.fluid.layers.learning_rate_scheduler import (
    piecewise_decay as piecewise_decay,
)
from paddle.framework import core as core
from paddle.optimizer.lr import PiecewiseDecay as PiecewiseDecay

from ..ps.utils.public import *
from .pass_base import PassBase as PassBase
from .pass_base import register_pass as register_pass

class AddLrDecayTablePass(PassBase):
    def __init__(self) -> None: ...

class AddListenAndServPass(PassBase):
    def __init__(self) -> None: ...

class AddRpcGlobalFlagsPass(PassBase):
    def __init__(self) -> None: ...

class AddOptimizerPass(PassBase):
    def __init__(self) -> None: ...

class AddGeoOptimizerPass(PassBase):
    def __init__(self) -> None: ...

class BuildPserverStartupProgramPass(PassBase):
    def __init__(self) -> None: ...

class DeleteUnusedInStartupPass(PassBase):
    def __init__(self) -> None: ...



from __future__ import annotations

from ..fluid.dygraph import ProgramTranslator as ProgramTranslator
from ..fluid.dygraph.io import TranslatedLayer as TranslatedLayer
from ..fluid.dygraph.jit import TracedLayer as TracedLayer
from ..fluid.dygraph.jit import declarative as to_static
from ..fluid.dygraph.jit import load as load
from ..fluid.dygraph.jit import not_to_static as not_to_static
from ..fluid.dygraph.jit import save as save
from ..fluid.dygraph.jit import set_code_level as set_code_level
from ..fluid.dygraph.jit import set_verbosity as set_verbosity



from __future__ import annotations

from typing import Any, Optional

from ... import Tensor, nn

class BNACConvLayer(nn.Layer):
    def __init__(
        self,
        num_channels: Any,
        num_filters: Any,
        filter_size: Any,
        stride: int = ...,
        pad: int = ...,
        groups: int = ...,
        act: str = ...,
    ) -> None: ...
    def forward(self, input: Any) -> Tensor: ...

class DenseLayer(nn.Layer):
    dropout: Any = ...
    bn_ac_func1: Any = ...
    bn_ac_func2: Any = ...
    dropout_func: Any = ...
    def __init__(self, num_channels: Any, growth_rate: Any, bn_size: Any, dropout: Any) -> None: ...
    def forward(self, input: Any) -> Tensor: ...

class DenseBlock(nn.Layer):
    dropout: Any = ...
    dense_layer_func: Any = ...
    def __init__(
        self,
        num_channels: Any,
        num_layers: Any,
        bn_size: Any,
        growth_rate: Any,
        dropout: Any,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, input: Any) -> Tensor: ...

class TransitionLayer(nn.Layer):
    conv_ac_func: Any = ...
    pool2d_avg: Any = ...
    def __init__(self, num_channels: Any, num_output_features: Any) -> None: ...
    def forward(self, input: Any) -> Tensor: ...

class ConvBNLayer(nn.Layer):
    def __init__(
        self,
        num_channels: Any,
        num_filters: Any,
        filter_size: Any,
        stride: int = ...,
        pad: int = ...,
        groups: int = ...,
        act: str = ...,
    ) -> None: ...
    def forward(self, input: Any) -> Tensor: ...

class DenseNet(nn.Layer):
    def __init__(
        self,
        layers: int = ...,
        bn_size: int = ...,
        dropout: float = ...,
        num_classes: int = ...,
        with_pool: bool = ...,
    ) -> None: ...
    def forward(self, input: Tensor) -> Tensor: ...
    __call__ = forward

def densenet121(
    pretrained: bool = ...,
    *,
    layers: int = ...,
    bn_size: int = ...,
    dropout: float = ...,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> DenseNet: ...
def densenet161(
    pretrained: bool = ...,
    *,
    layers: int = ...,
    bn_size: int = ...,
    dropout: float = ...,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> DenseNet: ...
def densenet169(
    pretrained: bool = ...,
    *,
    layers: int = ...,
    bn_size: int = ...,
    dropout: float = ...,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> DenseNet: ...
def densenet201(
    pretrained: bool = ...,
    *,
    layers: int = ...,
    bn_size: int = ...,
    dropout: float = ...,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> DenseNet: ...
def densenet264(
    pretrained: bool = ...,
    *,
    layers: int = ...,
    bn_size: int = ...,
    dropout: float = ...,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> DenseNet: ...



from __future__ import annotations

from . import datasets as datasets
from . import models as models
from . import transforms as transforms
from .image import get_image_backend as get_image_backend
from .image import image_load as image_load
from .image import set_image_backend as set_image_backend
from .models import VGG as VGG
from .models import AlexNet as AlexNet
from .models import DenseNet as DenseNet
from .models import GoogLeNet as GoogLeNet
from .models import InceptionV3 as InceptionV3
from .models import LeNet as LeNet
from .models import MobileNetV1 as MobileNetV1
from .models import MobileNetV2 as MobileNetV2
from .models import MobileNetV3Large as MobileNetV3Large
from .models import MobileNetV3Small as MobileNetV3Small
from .models import ResNet as ResNet
from .models import ShuffleNetV2 as ShuffleNetV2
from .models import SqueezeNet as SqueezeNet
from .models import alexnet as alexnet
from .models import densenet121 as densenet121
from .models import densenet161 as densenet161
from .models import densenet169 as densenet169
from .models import densenet201 as densenet201
from .models import densenet264 as densenet264
from .models import googlenet as googlenet
from .models import inception_v3 as inception_v3
from .models import mobilenet_v1 as mobilenet_v1
from .models import mobilenet_v2 as mobilenet_v2
from .models import mobilenet_v3_large as mobilenet_v3_large
from .models import mobilenet_v3_small as mobilenet_v3_small
from .models import resnet18 as resnet18
from .models import resnet34 as resnet34
from .models import resnet50 as resnet50
from .models import resnet101 as resnet101
from .models import resnet152 as resnet152
from .models import resnext50_32x4d as resnext50_32x4d
from .models import resnext50_64x4d as resnext50_64x4d
from .models import resnext101_32x4d as resnext101_32x4d
from .models import resnext101_64x4d as resnext101_64x4d
from .models import resnext152_32x4d as resnext152_32x4d
from .models import resnext152_64x4d as resnext152_64x4d
from .models import shufflenet_v2_swish as shufflenet_v2_swish
from .models import shufflenet_v2_x0_5 as shufflenet_v2_x0_5
from .models import shufflenet_v2_x0_25 as shufflenet_v2_x0_25
from .models import shufflenet_v2_x0_33 as shufflenet_v2_x0_33
from .models import shufflenet_v2_x1_0 as shufflenet_v2_x1_0
from .models import shufflenet_v2_x1_5 as shufflenet_v2_x1_5
from .models import shufflenet_v2_x2_0 as shufflenet_v2_x2_0
from .models import squeezenet1_0 as squeezenet1_0
from .models import squeezenet1_1 as squeezenet1_1
from .models import vgg11 as vgg11
from .models import vgg13 as vgg13
from .models import vgg16 as vgg16
from .models import vgg19 as vgg19
from .models import wide_resnet50_2 as wide_resnet50_2
from .models import wide_resnet101_2 as wide_resnet101_2



from __future__ import annotations

from typing import Any, Optional

from .line_search import strong_wolfe as strong_wolfe
from .utils import (
    check_initial_inverse_hessian_estimate as check_initial_inverse_hessian_estimate,
)
from .utils import check_input_type as check_input_type

def minimize_lbfgs(
    objective_func: Any,
    initial_position: Any,
    history_size: int = ...,
    max_iters: int = ...,
    tolerance_grad: float = ...,
    tolerance_change: float = ...,
    initial_inverse_hessian_estimate: Optional[Any] = ...,
    line_search_fn: str = ...,
    max_line_search_iters: int = ...,
    initial_step_length: float = ...,
    dtype: str = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from test_post_training_quantization_mobilenetv1 import TestPostTrainingQuantization

class TestPostTrainingForResnet50(TestPostTrainingQuantization):
    def test_post_training_resnet50(self) -> None: ...

class TestPostTrainingForResnet50ONNXFormat(TestPostTrainingQuantization):
    def test_post_training_resnet50(self) -> None: ...



from __future__ import annotations

from typing import Any

class DataFeedDesc:
    proto_desc: Any = ...
    def __init__(self, proto_file: Any) -> None: ...
    def set_batch_size(self, batch_size: Any) -> None: ...
    def set_dense_slots(self, dense_slots_name: Any) -> None: ...
    def set_use_slots(self, use_slots_name: Any) -> None: ...
    def desc(self): ...



from __future__ import annotations

from collections import defaultdict as defaultdict
from typing import Any, Optional

from paddle.fluid.framework import get_flags as get_flags

from .dist_attribute import OperatorDistributedAttribute as OperatorDistributedAttribute
from .dist_attribute import TensorDistributedAttribute as TensorDistributedAttribute
from .dist_op import DistributedOperator as DistributedOperator
from .dist_tensor import DistributedTensor as DistributedTensor
from .process_mesh import ProcessMesh as ProcessMesh

def get_default_distributed_context(): ...
def set_default_distributed_context(dist_context: Any) -> None: ...

class DistributedContext:
    def __init__(
        self,
        serial_main_prog: Optional[Any] = ...,
        serial_startup_prog: Optional[Any] = ...,
        dist_main_progs: Optional[Any] = ...,
        dist_startup_progs: Optional[Any] = ...,
    ) -> None: ...
    @property
    def serial_program(self): ...
    @property
    def serial_graph(self): ...
    @serial_program.setter
    def serial_program(self, program: Any) -> None: ...
    @property
    def serial_ordered_nodes(self): ...
    @property
    def process_meshes(self): ...
    @property
    def dist_op_context(self): ...
    @property
    def block_state(self): ...
    @property
    def dist_main_programs(self): ...
    @property
    def dist_startup_programs(self): ...
    def add_process_mesh(self, process_mesh: Any) -> None: ...
    def add_dist_tensor_for_program(self, dist_tensor: Any) -> None: ...
    def add_dist_op_for_program(self, dist_op: Any) -> None: ...
    def get_dist_tensor_for_program(self, serial_tensor: Any): ...
    def get_dist_tensor_for_graph(self, serial_tensor_node: Any): ...
    def get_dist_op_for_program(self, serial_op: Any): ...
    def del_dist_op_for_program(self, serial_tensor: Any) -> None: ...
    def get_dist_op_for_graph(self, serial_op_node: Any): ...
    def get_tensor_dist_attr_for_program(self, serial_tensor: Any): ...
    def get_tensor_dist_attr_for_program_with_id(self, tensor_id: Any): ...
    def set_tensor_dist_attr_for_program(self, serial_tensor: Any, dist_attr: Any) -> None: ...
    def get_tensor_dist_attr_for_graph(self, serial_tensor_node: Any): ...
    def get_op_dist_attr_for_program(self, serial_op: Any): ...
    def get_op_dist_attr_for_program_with_id(self, op_id: Any): ...
    def set_op_dist_attr_for_program(self, serial_op: Any, dist_attr: Any) -> None: ...
    def get_op_dist_attr_for_graph(self, serial_op_node: Any): ...
    def get_dist_attr_for_graph(self, serial_node: Any): ...
    def init_dist_attr_for_program(self) -> None: ...
    def order_nodes_by_program_order(self): ...
    def init_dist_attr_for_graph(self) -> None: ...
    def clear_dist_info_for_program(self) -> None: ...
    def clear_dist_info_for_graph(self) -> None: ...
    def copy_dist_attr_from_graph_to_program(self) -> None: ...
    def amend_dist_attr_for_program(self) -> None: ...
    def validate_dist_attr_for_program(self): ...
    def __deepcopy__(self, memo: Any): ...

class DistributedOperatorContext:
    grad_op_id_to_op_id: Any = ...
    already_init_sync_vars: Any = ...
    varname_mapping: Any = ...
    rank_id: Any = ...
    def __init__(self) -> None: ...
    def __deepcopy__(self, memo: Any): ...
    @property
    def dst_main_program(self): ...
    @dst_main_program.setter
    def dst_main_program(self, prog: Any) -> None: ...
    @property
    def main_block(self): ...
    @property
    def dst_startup_program(self): ...
    @dst_startup_program.setter
    def dst_startup_program(self, prog: Any) -> None: ...
    @property
    def startup_block(self): ...
    @property
    def work_block(self): ...
    @work_block.setter
    def work_block(self, block: Any) -> None: ...
    @property
    def cur_src_op(self): ...
    def prepare_context(self, src_op: Any): ...

class BlockState:
    nblock: int = ...
    forward_indices: Any = ...
    backward_indices: Any = ...
    backward_to_forward_index_map: Any = ...
    def __init__(self) -> None: ...
    def parse_forward_blocks(self, program: Any) -> None: ...
    def parse_backward_blocks(self, program: Any) -> None: ...



from __future__ import annotations

from typing import Any

URL_PREFIX: str
TEST_IMAGE_URL: Any
TEST_IMAGE_MD5: str
TEST_LABEL_URL: Any
TEST_LABEL_MD5: str
TRAIN_IMAGE_URL: Any
TRAIN_IMAGE_MD5: str
TRAIN_LABEL_URL: Any
TRAIN_LABEL_MD5: str

def reader_creator(image_filename: Any, label_filename: Any, buffer_size: Any): ...
def train(): ...
def test(): ...
def fetch() -> None: ...
